BlockState

Struct BlockState 

pub struct BlockState<'mc>(/* private fields */);

Implementations

Source

impl<'mc> BlockState<'mc>

pub fn block(&self) -> Result<Block<'mc>, Box<dyn Error>>

Gets the block represented by this block state.

pub fn data(&self) -> Result<MaterialData<'mc>, Box<dyn Error>>

Gets the metadata for this block state.

pub fn block_data(&self) -> Result<BlockData<'mc>, Box<dyn Error>>

Gets the data for this block state.

pub fn copy( &self, location: Option<impl Into<Location<'mc>>>, ) -> Result<BlockState<'mc>, Box<dyn Error>>

Copies the state to another block as an unplaced BlockState.

pub fn get_type(&self) -> Result<Material<'mc>, Box<dyn Error>>

Gets the type of this block state.

pub fn light_level(&self) -> Result<i8, Box<dyn Error>>

Gets the current light level of the block represented by this block state.

pub fn world(&self) -> Result<World<'mc>, Box<dyn Error>>

Gets the world which contains the block represented by this block state.

pub fn x(&self) -> Result<i32, Box<dyn Error>>

Gets the x-coordinate of this block state.

pub fn y(&self) -> Result<i32, Box<dyn Error>>

Gets the y-coordinate of this block state.

pub fn z(&self) -> Result<i32, Box<dyn Error>>

Gets the z-coordinate of this block state.

pub fn get_location( &self, loc: impl Into<Location<'mc>>, ) -> Result<Option<Location<'mc>>, Box<dyn Error>>

Stores the location of this block state in the provided Location object.

If the provided Location is null this method does nothing and returns null.

If this block state is not placed the location’s world will be null!

pub fn chunk(&self) -> Result<Chunk<'mc>, Box<dyn Error>>

Gets the chunk which contains the block represented by this block state.

pub fn set_data( &self, data: impl Into<MaterialData<'mc>>, ) -> Result<(), Box<dyn Error>>

Sets the metadata for this block state.

pub fn set_block_data( &self, data: impl Into<BlockData<'mc>>, ) -> Result<(), Box<dyn Error>>

Sets the data for this block state.

pub fn set_type( &self, val_type: impl Into<Material<'mc>>, ) -> Result<(), Box<dyn Error>>

Sets the type of this block state.

pub fn update( &self, force: Option<bool>, apply_physics: Option<bool>, ) -> Result<bool, Box<dyn Error>>

Attempts to update the block represented by this state, setting it to the new values as defined by this state.

If this state is not placed, this will have no effect and return true.

Unless force is true, this will not modify the state of a block if it is no longer the same type as it was when this state was taken. It will return false in this eventuality.

If force is true, it will set the type of the block to match the new state, set the state data and then return true.

If applyPhysics is true, it will trigger a physics update on surrounding blocks which could cause them to update or disappear.

pub fn raw_data(&self) -> Result<i8, Box<dyn Error>>

👎Deprecated
pub fn set_raw_data(&self, data: i8) -> Result<(), Box<dyn Error>>

👎Deprecated
pub fn is_placed(&self) -> Result<bool, Box<dyn Error>>

Returns whether this state is placed in the world.

Some methods will not work if the block state isn’t placed in the world.

pub fn set_metadata( &self, metadata_key: impl Into<String>, new_metadata_value: impl Into<MetadataValue<'mc>>, ) -> Result<(), Box<dyn Error>>

Sets a metadata value in the implementing object’s metadata store.

pub fn get_metadata( &self, metadata_key: impl Into<String>, ) -> Result<Vec<MetadataValue<'mc>>, Box<dyn Error>>

Returns a list of previously set metadata values from the implementing object’s metadata store.

pub fn has_metadata( &self, metadata_key: impl Into<String>, ) -> Result<bool, Box<dyn Error>>

Tests to see whether the implementing object contains the given metadata value in its metadata store.

pub fn remove_metadata( &self, metadata_key: impl Into<String>, owning_plugin: impl Into<Plugin<'mc>>, ) -> Result<(), Box<dyn Error>>

Removes the given metadata value from the implementing object’s metadata store.

pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>