Container

Struct Container 

pub struct Container<'mc>(/* private fields */);

Implementations

Source

impl<'mc> Container<'mc>

pub fn inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>

Gets the inventory of the block represented by this block state.

If the block was changed to a different type in the meantime, the returned inventory might no longer be valid.

If this block state is not placed this will return the captured inventory snapshot instead.

pub fn snapshot_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>

Gets the captured inventory snapshot of this container.

The returned inventory is not linked to any block. Any modifications to the returned inventory will not be applied to the block represented by this block state up until {@link #update(boolean, boolean)} has been called.

pub fn persistent_data_container( &self, ) -> Result<PersistentDataContainer<'mc>, Box<dyn Error>>

Returns a custom tag container capable of storing tags on the object. Note that the tags stored on this container are all stored under their own custom namespace therefore modifying default tags using this {@link PersistentDataHolder} is impossible.

This {@link PersistentDataHolder} is only linked to the snapshot instance stored by the {@link BlockState}. When storing changes on the {@link PersistentDataHolder}, the updated content will only be applied to the actual tile entity after one of the {@link #update()} methods is called.

pub fn block(&self) -> Result<Block<'mc>, Box<dyn Error>>

Gets the block associated with this holder.

pub fn is_locked(&self) -> Result<bool, Box<dyn Error>>

Checks if the container has a valid (non empty) key.

pub fn lock(&self) -> Result<String, Box<dyn Error>>

Gets the key needed to access the container.

pub fn set_lock(&self, key: impl Into<String>) -> Result<(), Box<dyn Error>>

Sets the key required to access this container. Set to null (or empty string) to remove key.

pub fn custom_name(&self) -> Result<Option<String>, Box<dyn Error>>

Gets the custom name on a mob or block. If there is no name this method will return null.

This value has no effect on players, they will always use their real name.

pub fn set_custom_name( &self, name: impl Into<String>, ) -> Result<(), Box<dyn Error>>

Sets a custom name on a mob or block. This name will be used in death messages and can be sent to the client as a nameplate over the mob.

Setting the name to null or an empty string will clear it.

This value has no effect on players, they will always use their real name.

pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>