EndGateway

Struct EndGateway 

pub struct EndGateway<'mc>(/* private fields */);

Implementations

Source

impl<'mc> EndGateway<'mc>

pub fn exit_location(&self) -> Result<Option<Location<'mc>>, Box<dyn Error>>

Gets the location that entities are teleported to when entering the gateway portal.

If this block state is not placed the location’s world will be null.

pub fn set_exit_location( &self, location: impl Into<Location<'mc>>, ) -> Result<(), Box<dyn Error>>

Sets the exit location that entities are teleported to when they enter the gateway portal.

If this block state is not placed the location’s world has to be null.

pub fn is_exact_teleport(&self) -> Result<bool, Box<dyn Error>>

Gets whether this gateway will teleport entities directly to the exit location instead of finding a nearby location.

pub fn set_exact_teleport(&self, exact: bool) -> Result<(), Box<dyn Error>>

Sets whether this gateway will teleport entities directly to the exit location instead of finding a nearby location.

pub fn age(&self) -> Result<i64, Box<dyn Error>>

Gets the age in ticks of the gateway.

If the age is less than 200 ticks a magenta beam will be emitted, whilst if it is a multiple of 2400 ticks a purple beam will be emitted.

pub fn set_age(&self, age: i64) -> Result<(), Box<dyn Error>>

Sets the age in ticks of the gateway.

If the age is less than 200 ticks a magenta beam will be emitted, whilst if it is a multiple of 2400 ticks a purple beam will be emitted.

pub fn persistent_data_container( &self, ) -> Result<PersistentDataContainer<'mc>, Box<dyn Error>>

Returns a custom tag container capable of storing tags on the object. Note that the tags stored on this container are all stored under their own custom namespace therefore modifying default tags using this {@link PersistentDataHolder} is impossible.

This {@link PersistentDataHolder} is only linked to the snapshot instance stored by the {@link BlockState}. When storing changes on the {@link PersistentDataHolder}, the updated content will only be applied to the actual tile entity after one of the {@link #update()} methods is called.

pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>