YamlConfigurationOptions

Struct YamlConfigurationOptions 

pub struct YamlConfigurationOptions<'mc>(/* private fields */);

Implementations

Source

impl<'mc> YamlConfigurationOptions<'mc>

pub fn configuration(&self) -> Result<YamlConfiguration<'mc>, Box<dyn Error>>

pub fn copy_defaults( &self, value: bool, ) -> Result<YamlConfigurationOptions<'mc>, Box<dyn Error>>

pub fn path_separator( &self, value: u16, ) -> Result<YamlConfigurationOptions<'mc>, Box<dyn Error>>

pub fn set_header( &self, value: Vec<JObject<'mc>>, ) -> Result<YamlConfigurationOptions<'mc>, Box<dyn Error>>

pub fn header( &self, value: impl Into<String>, ) -> Result<YamlConfigurationOptions<'mc>, Box<dyn Error>>

👎Deprecated
pub fn parse_comments( &self, value: bool, ) -> Result<YamlConfigurationOptions<'mc>, Box<dyn Error>>

pub fn copy_header( &self, value: bool, ) -> Result<YamlConfigurationOptions<'mc>, Box<dyn Error>>

👎Deprecated
pub fn indent( &self, value: Option<i32>, ) -> Result<YamlConfigurationOptions<'mc>, Box<dyn Error>>

Sets how much spaces should be used to indent each line.

The minimum value this may be is 2, and the maximum is 9.

pub fn width( &self, value: Option<i32>, ) -> Result<YamlConfigurationOptions<'mc>, Box<dyn Error>>

Sets how long a line can be, before it gets split.

pub fn get_header(&self) -> Result<Vec<String>, Box<dyn Error>>

Gets the header that will be applied to the top of the saved output.

This header will be commented out and applied directly at the top of the generated output of the {@link FileConfiguration}. It is not required to include a newline at the end of the header as it will automatically be applied, but you may include one if you wish for extra spacing.

If no comments exist, an empty list will be returned. A null entry represents an empty line and an empty String represents an empty comment line.

pub fn footer(&self) -> Result<Vec<String>, Box<dyn Error>>

Gets the footer that will be applied to the bottom of the saved output.

This footer will be commented out and applied directly at the bottom of the generated output of the {@link FileConfiguration}. It is not required to include a newline at the beginning of the footer as it will automatically be applied, but you may include one if you wish for extra spacing.

If no comments exist, an empty list will be returned. A null entry represents an empty line and an empty String represents an empty comment line.

pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>