pub struct Drowned<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> Drowned<'mc>
impl<'mc> Drowned<'mc>
Sourcepub fn is_baby(&self) -> Result<bool, Box<dyn Error>>
👎Deprecated
pub fn is_baby(&self) -> Result<bool, Box<dyn Error>>
Gets whether the zombie is a baby
Sourcepub fn set_baby(&self, flag: Option<bool>) -> Result<(), Box<dyn Error>>
👎Deprecated
pub fn set_baby(&self, flag: Option<bool>) -> Result<(), Box<dyn Error>>
Sets whether the zombie is a baby
Sourcepub fn is_villager(&self) -> Result<bool, Box<dyn Error>>
👎Deprecated
pub fn is_villager(&self) -> Result<bool, Box<dyn Error>>
Gets whether the zombie is a villager
pub fn set_villager(&self, flag: bool) -> Result<(), Box<dyn Error>>
pub fn set_villager_profession( &self, profession: impl Into<VillagerProfession<'mc>>, ) -> Result<(), Box<dyn Error>>
pub fn villager_profession( &self, ) -> Result<Option<VillagerProfession<'mc>>, Box<dyn Error>>
Sourcepub fn is_converting(&self) -> Result<bool, Box<dyn Error>>
pub fn is_converting(&self) -> Result<bool, Box<dyn Error>>
Get if this entity is in the process of converting to a Drowned as a result of being underwater.
Sourcepub fn conversion_time(&self) -> Result<i32, Box<dyn Error>>
pub fn conversion_time(&self) -> Result<i32, Box<dyn Error>>
Gets the amount of ticks until this entity will be converted to a Drowned as a result of being underwater. When this reaches 0, the entity will be converted.
Sourcepub fn set_conversion_time(&self, time: i32) -> Result<(), Box<dyn Error>>
pub fn set_conversion_time(&self, time: i32) -> Result<(), Box<dyn Error>>
Sets the amount of ticks until this entity will be converted to a Drowned as a result of being underwater. When this reaches 0, the entity will be converted. A value of less than 0 will stop the current conversion process without converting the current entity.
Sourcepub fn can_break_doors(&self) -> Result<bool, Box<dyn Error>>
pub fn can_break_doors(&self) -> Result<bool, Box<dyn Error>>
Gets whether this zombie can break doors
Sourcepub fn set_can_break_doors(&self, flag: bool) -> Result<(), Box<dyn Error>>
pub fn set_can_break_doors(&self, flag: bool) -> Result<(), Box<dyn Error>>
Sets whether this zombie can break doors This will be ignored if the entity is a Drowned. Will also stop the action if the entity is currently breaking a door.
Sourcepub fn set_age_lock(&self, lock: bool) -> Result<(), Box<dyn Error>>
👎Deprecated
pub fn set_age_lock(&self, lock: bool) -> Result<(), Box<dyn Error>>
Lock the age of the animal, setting this will prevent the animal from maturing or getting ready for mating.
Sourcepub fn can_breed(&self) -> Result<bool, Box<dyn Error>>
👎Deprecated
pub fn can_breed(&self) -> Result<bool, Box<dyn Error>>
Return the ability to breed of the animal.
Sourcepub fn set_breed(&self, breed: bool) -> Result<(), Box<dyn Error>>
👎Deprecated
pub fn set_breed(&self, breed: bool) -> Result<(), Box<dyn Error>>
Set breedability of the animal, if the animal is a baby and set to breed it will instantly grow up.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>