EnderDragonPart

Struct EnderDragonPart 

pub struct EnderDragonPart<'mc>(/* private fields */);

Implementations

Source

impl<'mc> EnderDragonPart<'mc>

pub fn parent(&self) -> Result<EnderDragon<'mc>, Box<dyn Error>>

pub fn get_location( &self, loc: impl Into<Location<'mc>>, ) -> Result<Option<Location<'mc>>, Box<dyn Error>>

Stores the entity’s current position in the provided Location object.

If the provided Location is null this method does nothing and returns null.

pub fn set_velocity( &self, velocity: impl Into<Vector<'mc>>, ) -> Result<(), Box<dyn Error>>

Sets this entity’s velocity in meters per tick

pub fn velocity(&self) -> Result<Vector<'mc>, Box<dyn Error>>

Gets this entity’s current velocity

pub fn height(&self) -> Result<f64, Box<dyn Error>>

Gets the entity’s height

pub fn width(&self) -> Result<f64, Box<dyn Error>>

Gets the entity’s width

pub fn bounding_box(&self) -> Result<BoundingBox<'mc>, Box<dyn Error>>

Gets the entity’s current bounding box.

The returned bounding box reflects the entity’s current location and size.

pub fn is_on_ground(&self) -> Result<bool, Box<dyn Error>>

Returns true if the entity is supported by a block. This value is a state updated by the server and is not recalculated unless the entity moves.

pub fn is_in_water(&self) -> Result<bool, Box<dyn Error>>

Returns true if the entity is in water.

pub fn world(&self) -> Result<World<'mc>, Box<dyn Error>>

Gets the current world this entity resides in

pub fn set_rotation(&self, yaw: f32, pitch: f32) -> Result<(), Box<dyn Error>>

Sets the entity’s rotation.

Note that if the entity is affected by AI, it may override this rotation.

pub fn teleport( &self, location: impl Into<Location<'mc>>, cause: Option<impl Into<PlayerTeleportEventTeleportCause<'mc>>>, ) -> Result<bool, Box<dyn Error>>

Teleports this entity to the given location. If this entity is riding a vehicle, it will be dismounted prior to teleportation.

pub fn get_nearby_entities( &self, x: f64, y: f64, z: f64, ) -> Result<Vec<Entity<'mc>>, Box<dyn Error>>

Returns a list of entities within a bounding box centered around this entity

pub fn entity_id(&self) -> Result<i32, Box<dyn Error>>

Returns a unique id for this entity

pub fn fire_ticks(&self) -> Result<i32, Box<dyn Error>>

Returns the entity’s current fire ticks (ticks before the entity stops being on fire).

pub fn max_fire_ticks(&self) -> Result<i32, Box<dyn Error>>

Returns the entity’s maximum fire ticks.

pub fn set_fire_ticks(&self, ticks: i32) -> Result<(), Box<dyn Error>>

Sets the entity’s current fire ticks (ticks before the entity stops being on fire).

pub fn set_visual_fire(&self, fire: bool) -> Result<(), Box<dyn Error>>

Sets if the entity has visual fire (it will always appear to be on fire).

pub fn is_visual_fire(&self) -> Result<bool, Box<dyn Error>>

Gets if the entity has visual fire (it will always appear to be on fire).

pub fn freeze_ticks(&self) -> Result<i32, Box<dyn Error>>

Returns the entity’s current freeze ticks (amount of ticks the entity has been in powdered snow).

pub fn max_freeze_ticks(&self) -> Result<i32, Box<dyn Error>>

Returns the entity’s maximum freeze ticks (amount of ticks before it will be fully frozen)

pub fn set_freeze_ticks(&self, ticks: i32) -> Result<(), Box<dyn Error>>

Sets the entity’s current freeze ticks (amount of ticks the entity has been in powdered snow).

pub fn is_frozen(&self) -> Result<bool, Box<dyn Error>>

Gets if the entity is fully frozen (it has been in powdered snow for max freeze ticks).

pub fn remove(&self) -> Result<(), Box<dyn Error>>

Mark the entity’s removal.

pub fn is_dead(&self) -> Result<bool, Box<dyn Error>>

Returns true if this entity has been marked for removal.

pub fn is_valid(&self) -> Result<bool, Box<dyn Error>>

Returns false if the entity has died, been despawned for some other reason, or has not been added to the world.

pub fn server(&self) -> Result<Server<'mc>, Box<dyn Error>>

Gets the {@link Server} that contains this Entity

pub fn is_persistent(&self) -> Result<bool, Box<dyn Error>>

Returns true if the entity gets persisted.

By default all entities are persistent. An entity will also not get persisted, if it is riding an entity that is not persistent.

The persistent flag on players controls whether or not to save their playerdata file when they quit. If a player is directly or indirectly riding a non-persistent entity, the vehicle at the root and all its passengers won’t get persisted.

This should not be confused with {@link LivingEntity#setRemoveWhenFarAway(boolean)} which controls despawning of living entities.

pub fn set_persistent(&self, persistent: bool) -> Result<(), Box<dyn Error>>

Sets whether or not the entity gets persisted.

pub fn passenger(&self) -> Result<Option<Entity<'mc>>, Box<dyn Error>>

👎Deprecated

Gets the primary passenger of a vehicle. For vehicles that could have multiple passengers, this will only return the primary passenger.

pub fn set_passenger( &self, passenger: impl Into<Entity<'mc>>, ) -> Result<bool, Box<dyn Error>>

👎Deprecated

Set the passenger of a vehicle.

pub fn passengers(&self) -> Result<Vec<Entity<'mc>>, Box<dyn Error>>

Gets a list of passengers of this vehicle.

The returned list will not be directly linked to the entity’s current passengers, and no guarantees are made as to its mutability.

pub fn add_passenger( &self, passenger: impl Into<Entity<'mc>>, ) -> Result<bool, Box<dyn Error>>

Add a passenger to the vehicle.

pub fn remove_passenger( &self, passenger: impl Into<Entity<'mc>>, ) -> Result<bool, Box<dyn Error>>

Remove a passenger from the vehicle.

pub fn is_empty(&self) -> Result<bool, Box<dyn Error>>

Check if a vehicle has passengers.

pub fn eject(&self) -> Result<bool, Box<dyn Error>>

Eject any passenger.

pub fn fall_distance(&self) -> Result<f32, Box<dyn Error>>

Returns the distance this entity has fallen

pub fn set_fall_distance(&self, distance: f32) -> Result<(), Box<dyn Error>>

Sets the fall distance for this entity

pub fn set_last_damage_cause( &self, event: impl Into<EntityDamageEvent<'mc>>, ) -> Result<(), Box<dyn Error>>

👎Deprecated

Record the last {@link EntityDamageEvent} inflicted on this entity

pub fn last_damage_cause( &self, ) -> Result<Option<EntityDamageEvent<'mc>>, Box<dyn Error>>

Retrieve the last {@link EntityDamageEvent} inflicted on this entity. This event may have been cancelled.

pub fn unique_id(&self) -> Result<JavaUUID<'mc>, Box<dyn Error>>

Returns a unique and persistent id for this entity

pub fn ticks_lived(&self) -> Result<i32, Box<dyn Error>>

Gets the amount of ticks this entity has lived for.

This is the equivalent to “age” in entities.

pub fn set_ticks_lived(&self, value: i32) -> Result<(), Box<dyn Error>>

Sets the amount of ticks this entity has lived for.

This is the equivalent to “age” in entities. May not be less than one tick.

pub fn play_effect( &self, val_type: impl Into<EntityEffect<'mc>>, ) -> Result<(), Box<dyn Error>>

Performs the specified {@link EntityEffect} for this entity.

This will be viewable to all players near the entity.

If the effect is not applicable to this class of entity, it will not play.

pub fn get_type(&self) -> Result<EntityType<'mc>, Box<dyn Error>>

Get the type of the entity.

pub fn swim_sound(&self) -> Result<Sound<'mc>, Box<dyn Error>>

Get the {@link Sound} this entity makes while swimming.

pub fn swim_splash_sound(&self) -> Result<Sound<'mc>, Box<dyn Error>>

Get the {@link Sound} this entity makes when splashing in water. For most entities, this is just {@link Sound#ENTITY_GENERIC_SPLASH}.

pub fn swim_high_speed_splash_sound(&self) -> Result<Sound<'mc>, Box<dyn Error>>

Get the {@link Sound} this entity makes when splashing in water at high speeds. For most entities, this is just {@link Sound#ENTITY_GENERIC_SPLASH}.

pub fn is_inside_vehicle(&self) -> Result<bool, Box<dyn Error>>

Returns whether this entity is inside a vehicle.

pub fn leave_vehicle(&self) -> Result<bool, Box<dyn Error>>

Leave the current vehicle. If the entity is currently in a vehicle (and is removed from it), true will be returned, otherwise false will be returned.

pub fn vehicle(&self) -> Result<Option<Entity<'mc>>, Box<dyn Error>>

Get the vehicle that this entity is inside. If there is no vehicle, null will be returned.

pub fn set_custom_name_visible(&self, flag: bool) -> Result<(), Box<dyn Error>>

Sets whether or not to display the mob’s custom name client side. The name will be displayed above the mob similarly to a player.

This value has no effect on players, they will always display their name.

pub fn is_custom_name_visible(&self) -> Result<bool, Box<dyn Error>>

Gets whether or not the mob’s custom name is displayed client side.

This value has no effect on players, they will always display their name.

pub fn set_visible_by_default( &self, visible: bool, ) -> Result<(), Box<dyn Error>>

Sets whether or not this entity is visible by default. If this entity is not visible by default, then {@link Player#showEntity(org.bukkit.plugin.Plugin, org.bukkit.entity.Entity)} will need to be called before the entity is visible to a given player.

pub fn is_visible_by_default(&self) -> Result<bool, Box<dyn Error>>

Gets whether or not this entity is visible by default. If this entity is not visible by default, then {@link Player#showEntity(org.bukkit.plugin.Plugin, org.bukkit.entity.Entity)} will need to be called before the entity is visible to a given player.

pub fn tracked_by(&self) -> Result<JavaSet<'mc>, Box<dyn Error>>

Get all players that are currently tracking this entity.

‘Tracking’ means that this entity has been sent to the player and that they are receiving updates on its state. Note that the client’s {@code ‘Entity Distance’} setting does not affect the range at which entities are tracked.

pub fn set_glowing(&self, flag: bool) -> Result<(), Box<dyn Error>>

Sets whether the entity has a team colored (default: white) glow. nb: this refers to the ‘Glowing’ entity property, not whether a glowing potion effect is applied

pub fn is_glowing(&self) -> Result<bool, Box<dyn Error>>

Gets whether the entity is glowing or not. nb: this refers to the ‘Glowing’ entity property, not whether a glowing potion effect is applied

pub fn set_invulnerable(&self, flag: bool) -> Result<(), Box<dyn Error>>

Sets whether the entity is invulnerable or not.

When an entity is invulnerable it can only be damaged by players in creative mode.

pub fn is_invulnerable(&self) -> Result<bool, Box<dyn Error>>

Gets whether the entity is invulnerable or not.

pub fn is_silent(&self) -> Result<bool, Box<dyn Error>>

Gets whether the entity is silent or not.

pub fn set_silent(&self, flag: bool) -> Result<(), Box<dyn Error>>

Sets whether the entity is silent or not.

When an entity is silent it will not produce any sound.

pub fn has_gravity(&self) -> Result<bool, Box<dyn Error>>

Returns whether gravity applies to this entity.

pub fn set_gravity(&self, gravity: bool) -> Result<(), Box<dyn Error>>

Sets whether gravity applies to this entity.

pub fn portal_cooldown(&self) -> Result<i32, Box<dyn Error>>

Gets the period of time (in ticks) before this entity can use a portal.

pub fn set_portal_cooldown(&self, cooldown: i32) -> Result<(), Box<dyn Error>>

Sets the period of time (in ticks) before this entity can use a portal.

pub fn scoreboard_tags(&self) -> Result<JavaSet<'mc>, Box<dyn Error>>

Returns a set of tags for this entity.

Entities can have no more than 1024 tags.

pub fn add_scoreboard_tag( &self, tag: impl Into<String>, ) -> Result<bool, Box<dyn Error>>

Add a tag to this entity.

Entities can have no more than 1024 tags.

pub fn remove_scoreboard_tag( &self, tag: impl Into<String>, ) -> Result<bool, Box<dyn Error>>

Removes a given tag from this entity.

pub fn piston_move_reaction( &self, ) -> Result<PistonMoveReaction<'mc>, Box<dyn Error>>

Returns the reaction of the entity when moved by a piston.

pub fn facing(&self) -> Result<BlockFace<'mc>, Box<dyn Error>>

Get the closest cardinal {@link BlockFace} direction an entity is currently facing.

This will not return any non-cardinal directions such as {@link BlockFace#UP} or {@link BlockFace#DOWN}.

{@link Hanging} entities will override this call and thus their behavior may be different.

pub fn pose(&self) -> Result<Pose<'mc>, Box<dyn Error>>

Gets the entity’s current pose. Note that the pose is only updated at the end of a tick, so may be inconsistent with other methods. eg {@link Player#isSneaking()} being true does not imply the current pose will be {@link Pose#SNEAKING}

pub fn spawn_category(&self) -> Result<SpawnCategory<'mc>, Box<dyn Error>>

Get the category of spawn to which this entity belongs.

pub fn is_in_world(&self) -> Result<bool, Box<dyn Error>>

Checks if this entity has been spawned in a world.

Entities not spawned in a world will not tick, be sent to players, or be saved to the server files.

pub fn as_string(&self) -> Result<Option<String>, Box<dyn Error>>

Get this entity as an NBT string.

This string should not be relied upon as a serializable value.

pub fn create_snapshot( &self, ) -> Result<Option<EntitySnapshot<'mc>>, Box<dyn Error>>

Crates an {@link EntitySnapshot} representing the current state of this entity.

pub fn copy( &self, to: Option<impl Into<Location<'mc>>>, ) -> Result<Entity<'mc>, Box<dyn Error>>

Creates a copy of this entity and all its data. Spawns the copy at the given location.

Note: Players cannot be copied.

pub fn damage( &self, amount: f64, damage_source: Option<impl Into<DamageSource<'mc>>>, ) -> Result<(), Box<dyn Error>>

Deals the given amount of damage to this entity from a specified {@link DamageSource}.

pub fn health(&self) -> Result<f64, Box<dyn Error>>

Gets the entity’s health from 0 to {@link #getMaxHealth()}, where 0 is dead.

pub fn set_health(&self, health: f64) -> Result<(), Box<dyn Error>>

Sets the entity’s health from 0 to {@link #getMaxHealth()}, where 0 is dead.

pub fn absorption_amount(&self) -> Result<f64, Box<dyn Error>>

Gets the entity’s absorption amount.

pub fn set_absorption_amount(&self, amount: f64) -> Result<(), Box<dyn Error>>

Sets the entity’s absorption amount.

Note: The amount is capped to the value of {@link Attribute#GENERIC_MAX_ABSORPTION}. The effect of this method on that attribute is currently unspecified and subject to change.

pub fn max_health(&self) -> Result<f64, Box<dyn Error>>

👎Deprecated

Gets the maximum health this entity has.

pub fn set_max_health(&self, health: f64) -> Result<(), Box<dyn Error>>

👎Deprecated

Sets the maximum health this entity can have.If the health of the entity is above the value provided it will be set to that value.Note: An entity with a health bar ({@link Player}, {@link EnderDragon}, {@link Wither}, etc…} will have their bar scaled accordingly.

pub fn reset_max_health(&self) -> Result<(), Box<dyn Error>>

👎Deprecated

Resets the max health to the original amount.

pub fn set_metadata( &self, metadata_key: impl Into<String>, new_metadata_value: impl Into<MetadataValue<'mc>>, ) -> Result<(), Box<dyn Error>>

Sets a metadata value in the implementing object’s metadata store.

pub fn get_metadata( &self, metadata_key: impl Into<String>, ) -> Result<Vec<MetadataValue<'mc>>, Box<dyn Error>>

Returns a list of previously set metadata values from the implementing object’s metadata store.

pub fn has_metadata( &self, metadata_key: impl Into<String>, ) -> Result<bool, Box<dyn Error>>

Tests to see whether the implementing object contains the given metadata value in its metadata store.

pub fn remove_metadata( &self, metadata_key: impl Into<String>, owning_plugin: impl Into<Plugin<'mc>>, ) -> Result<(), Box<dyn Error>>

Removes the given metadata value from the implementing object’s metadata store.

pub fn send_message( &self, sender: impl Into<JavaUUID<'mc>>, messages: Option<impl Into<String>>, ) -> Result<(), Box<dyn Error>>

Sends this sender multiple messages

pub fn name(&self) -> Result<String, Box<dyn Error>>

Gets the name of this command sender

pub fn custom_name(&self) -> Result<Option<String>, Box<dyn Error>>

Gets the custom name on a mob or block. If there is no name this method will return null.

This value has no effect on players, they will always use their real name.

pub fn set_custom_name( &self, name: impl Into<String>, ) -> Result<(), Box<dyn Error>>

Sets a custom name on a mob or block. This name will be used in death messages and can be sent to the client as a nameplate over the mob.

Setting the name to null or an empty string will clear it.

This value has no effect on players, they will always use their real name.

pub fn persistent_data_container( &self, ) -> Result<PersistentDataContainer<'mc>, Box<dyn Error>>

Returns a custom tag container capable of storing tags on the object. Note that the tags stored on this container are all stored under their own custom namespace therefore modifying default tags using this {@link PersistentDataHolder} is impossible.

pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>