pub struct Turtle<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> Turtle<'mc>
impl<'mc> Turtle<'mc>
Sourcepub fn is_laying_egg(&self) -> Result<bool, Box<dyn Error>>
pub fn is_laying_egg(&self) -> Result<bool, Box<dyn Error>>
Gets whether the turtle is laying an egg
Sourcepub fn breed_cause(&self) -> Result<Option<JavaUUID<'mc>>, Box<dyn Error>>
pub fn breed_cause(&self) -> Result<Option<JavaUUID<'mc>>, Box<dyn Error>>
Get the UUID of the entity that caused this entity to enter the {@link #canBreed()} state.
Sourcepub fn set_breed_cause(
&self,
uuid: impl Into<JavaUUID<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_breed_cause( &self, uuid: impl Into<JavaUUID<'mc>>, ) -> Result<(), Box<dyn Error>>
Set the UUID of the entity that caused this entity to enter the {@link #canBreed()} state.
Sourcepub fn is_love_mode(&self) -> Result<bool, Box<dyn Error>>
pub fn is_love_mode(&self) -> Result<bool, Box<dyn Error>>
Get whether or not this entity is in love mode and will produce offspring with another entity in love mode. Will return true if and only if {@link #getLoveModeTicks()} is greater than 0.
Sourcepub fn love_mode_ticks(&self) -> Result<i32, Box<dyn Error>>
pub fn love_mode_ticks(&self) -> Result<i32, Box<dyn Error>>
Get the amount of ticks remaining for this entity in love mode. If the entity is not in love mode, 0 will be returned.
Sourcepub fn set_love_mode_ticks(&self, ticks: i32) -> Result<(), Box<dyn Error>>
pub fn set_love_mode_ticks(&self, ticks: i32) -> Result<(), Box<dyn Error>>
Set the amount of ticks for which this entity should be in love mode. Setting the love mode ticks to 600 is the equivalent of a player feeding the entity their breeding item of choice.
Sourcepub fn is_breed_item(
&self,
material: impl Into<Material<'mc>>,
) -> Result<bool, Box<dyn Error>>
pub fn is_breed_item( &self, material: impl Into<Material<'mc>>, ) -> Result<bool, Box<dyn Error>>
Check if the provided ItemStack is the correct item used for breeding this entity..
Sourcepub fn set_age_lock(&self, lock: bool) -> Result<(), Box<dyn Error>>
pub fn set_age_lock(&self, lock: bool) -> Result<(), Box<dyn Error>>
Lock the age of the animal, setting this will prevent the animal from maturing or getting ready for mating.
Sourcepub fn can_breed(&self) -> Result<bool, Box<dyn Error>>
pub fn can_breed(&self) -> Result<bool, Box<dyn Error>>
Return the ability to breed of the animal.
Sourcepub fn set_breed(&self, breed: bool) -> Result<(), Box<dyn Error>>
pub fn set_breed(&self, breed: bool) -> Result<(), Box<dyn Error>>
Set breedability of the animal, if the animal is a baby and set to breed it will instantly grow up.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>