pub struct EntityKnockbackEvent<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> EntityKnockbackEvent<'mc>
impl<'mc> EntityKnockbackEvent<'mc>
pub fn new( jni: &SharedJNIEnv<'mc>, entity: impl Into<LivingEntity<'mc>>, cause: impl Into<EntityKnockbackEventKnockbackCause<'mc>>, force: f64, raw_knockback: impl Into<Vector<'mc>>, knockback: impl Into<Vector<'mc>>, ) -> Result<EntityKnockbackEvent<'mc>, Box<dyn Error>>
pub fn entity(&self) -> Result<LivingEntity<'mc>, Box<dyn Error>>
Sourcepub fn cause(
&self,
) -> Result<EntityKnockbackEventKnockbackCause<'mc>, Box<dyn Error>>
pub fn cause( &self, ) -> Result<EntityKnockbackEventKnockbackCause<'mc>, Box<dyn Error>>
Gets the cause of the knockback.
Sourcepub fn force(&self) -> Result<f64, Box<dyn Error>>
pub fn force(&self) -> Result<f64, Box<dyn Error>>
Gets the raw force of the knockback.
This value is based on factors such as the {@link Enchantment#KNOCKBACK} level of an attacker and the {@link Attribute#GENERIC_KNOCKBACK_RESISTANCE} of the entity.
Sourcepub fn knockback(&self) -> Result<Vector<'mc>, Box<dyn Error>>
pub fn knockback(&self) -> Result<Vector<'mc>, Box<dyn Error>>
Gets the raw knockback force that will be applied to the entity.
This value is read-only, changes made to it will not have any effect on the final knockback received.
Sourcepub fn final_knockback(&self) -> Result<Vector<'mc>, Box<dyn Error>>
pub fn final_knockback(&self) -> Result<Vector<'mc>, Box<dyn Error>>
Gets the force that will be applied to the entity.
In contrast to {@link EntityKnockbackEvent#getKnockback()} this value is affected by the entities current velocity and whether they are touching the ground.
Note: this method returns a copy, changes must be applied with {@link #setFinalKnockback(Vector)}.
Sourcepub fn set_final_knockback(
&self,
knockback: impl Into<Vector<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_final_knockback( &self, knockback: impl Into<Vector<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the force that will be applied to the entity.
pub fn is_cancelled(&self) -> Result<bool, Box<dyn Error>>
pub fn set_cancelled(&self, cancel: bool) -> Result<(), Box<dyn Error>>
pub fn handlers(&self) -> Result<HandlerList<'mc>, Box<dyn Error>>
pub fn handler_list( jni: &SharedJNIEnv<'mc>, ) -> Result<HandlerList<'mc>, Box<dyn Error>>
Sourcepub fn entity_type(&self) -> Result<EntityType<'mc>, Box<dyn Error>>
pub fn entity_type(&self) -> Result<EntityType<'mc>, Box<dyn Error>>
Gets the EntityType of the Entity involved in this event.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>