InventoryClickEvent

Struct InventoryClickEvent 

pub struct InventoryClickEvent<'mc>(/* private fields */);

Implementations

Source

impl<'mc> InventoryClickEvent<'mc>

pub fn new( jni: &SharedJNIEnv<'mc>, view: impl Into<InventoryView<'mc>>, val_type: impl Into<InventoryTypeSlotType<'mc>>, slot: i32, click: impl Into<ClickType<'mc>>, action: impl Into<InventoryAction<'mc>>, key: Option<i32>, ) -> Result<InventoryClickEvent<'mc>, Box<dyn Error>>

pub fn slot_type(&self) -> Result<InventoryTypeSlotType<'mc>, Box<dyn Error>>

Gets the type of slot that was clicked.

pub fn cursor(&self) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>

Gets the current ItemStack on the cursor.

pub fn current_item(&self) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>

Gets the ItemStack currently in the clicked slot.

pub fn is_right_click(&self) -> Result<bool, Box<dyn Error>>

Gets whether or not the ClickType for this event represents a right click.

pub fn is_left_click(&self) -> Result<bool, Box<dyn Error>>

Gets whether or not the ClickType for this event represents a left click.

pub fn is_shift_click(&self) -> Result<bool, Box<dyn Error>>

Gets whether the ClickType for this event indicates that the key was pressed down when the click was made.

pub fn set_cursor( &self, stack: impl Into<ItemStack<'mc>>, ) -> Result<(), Box<dyn Error>>

👎Deprecated

Sets the item on the cursor.

pub fn set_current_item( &self, stack: impl Into<ItemStack<'mc>>, ) -> Result<(), Box<dyn Error>>

Sets the ItemStack currently in the clicked slot.

pub fn clicked_inventory( &self, ) -> Result<Option<Inventory<'mc>>, Box<dyn Error>>

Gets the inventory corresponding to the clicked slot.

pub fn slot(&self) -> Result<i32, Box<dyn Error>>

The slot number that was clicked, ready for passing to {@link Inventory#getItem(int)}. Note that there may be two slots with the same slot number, since a view links two different inventories.

pub fn raw_slot(&self) -> Result<i32, Box<dyn Error>>

The raw slot number clicked, ready for passing to {@link InventoryView #getItem(int)} This slot number is unique for the view.

pub fn hotbar_button(&self) -> Result<i32, Box<dyn Error>>

If the ClickType is NUMBER_KEY, this method will return the index of the pressed key (0-8).

pub fn action(&self) -> Result<InventoryAction<'mc>, Box<dyn Error>>

Gets the InventoryAction that triggered this event.

This action cannot be changed, and represents what the normal outcome of the event will be. To change the behavior of this InventoryClickEvent, changes must be manually applied.

pub fn click(&self) -> Result<ClickType<'mc>, Box<dyn Error>>

Gets the ClickType for this event.

This is insulated against changes to the inventory by other plugins.

pub fn handlers(&self) -> Result<HandlerList<'mc>, Box<dyn Error>>

pub fn handler_list( jni: &SharedJNIEnv<'mc>, ) -> Result<HandlerList<'mc>, Box<dyn Error>>

pub fn who_clicked(&self) -> Result<HumanEntity<'mc>, Box<dyn Error>>

Gets the player who performed the click.

pub fn set_result( &self, new_result: impl Into<EventResult<'mc>>, ) -> Result<(), Box<dyn Error>>

Sets the result of this event. This will change whether or not this event is considered cancelled.

pub fn result(&self) -> Result<EventResult<'mc>, Box<dyn Error>>

Gets the {@link org.bukkit.event.Event.Result} of this event. The Result describes the behavior that will be applied to the inventory in relation to this event.

pub fn is_cancelled(&self) -> Result<bool, Box<dyn Error>>

Gets whether or not this event is cancelled. This is based off of the Result value returned by {@link #getResult()}.Result.ALLOW and Result.DEFAULT will result in a returned value of false, but Result.DENY will result in a returned value of true.

{@inheritDoc}

pub fn set_cancelled(&self, to_cancel: bool) -> Result<(), Box<dyn Error>>

Proxy method to {@link #setResult(org.bukkit.event.Event.Result)} for the Cancellable interface. {@link #setResult(org.bukkit.event.Event.Result)} is preferred, as it allows you to specify the Result beyond Result.DENY and Result.ALLOW.

{@inheritDoc}

pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>