BlockPopulator

Struct BlockPopulator 

pub struct BlockPopulator<'mc>(/* private fields */);

Implementations

Source

impl<'mc> BlockPopulator<'mc>

pub fn from_extendable( env: &SharedJNIEnv<'mc>, plugin: &'mc Plugin<'_>, address: i32, lib_name: String, name: String, ) -> Result<Self, Box<dyn Error>>

pub fn new( jni: &SharedJNIEnv<'mc>, ) -> Result<BlockPopulator<'mc>, Box<dyn Error>>

pub fn populate( &self, world_info: impl Into<WorldInfo<'mc>>, random: impl Into<JavaRandom<'mc>>, chunk_x: i32, chunk_z: Option<i32>, limited_region: Option<impl Into<LimitedRegion<'mc>>>, ) -> Result<(), Box<dyn Error>>

Populates an area of blocks at or around the given chunk.

Notes:

This method should never attempt to get the Chunk at the passed coordinates, as doing so may cause an infinite loop

This method should never modify a {@link LimitedRegion} at a later point of time.

This method must be completely thread safe and able to handle multiple concurrent callers.

No physics are applied, whether or not it is set to true in {@link org.bukkit.block.BlockState#update(boolean, boolean)}

Only use the {@link org.bukkit.block.BlockState} returned by {@link LimitedRegion}, never use methods from a {@link World} to modify the chunk.

pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>