pub struct GeneratedStructure<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> GeneratedStructure<'mc>
impl<'mc> GeneratedStructure<'mc>
Sourcepub fn bounding_box(&self) -> Result<BoundingBox<'mc>, Box<dyn Error>>
pub fn bounding_box(&self) -> Result<BoundingBox<'mc>, Box<dyn Error>>
Gets the bounding box of this placed structure.
Sourcepub fn structure(&self) -> Result<Structure<'mc>, Box<dyn Error>>
pub fn structure(&self) -> Result<Structure<'mc>, Box<dyn Error>>
Gets the structure that this PlacedStructure represents.
Sourcepub fn pieces(&self) -> Result<Vec<StructurePiece<'mc>>, Box<dyn Error>>
pub fn pieces(&self) -> Result<Vec<StructurePiece<'mc>>, Box<dyn Error>>
Gets all the {@link StructurePiece} that make up this PlacedStructure.
Sourcepub fn persistent_data_container(
&self,
) -> Result<PersistentDataContainer<'mc>, Box<dyn Error>>
pub fn persistent_data_container( &self, ) -> Result<PersistentDataContainer<'mc>, Box<dyn Error>>
Returns a custom tag container capable of storing tags on the object. Note that the tags stored on this container are all stored under their own custom namespace therefore modifying default tags using this {@link PersistentDataHolder} is impossible.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>