pub struct BlastingRecipe<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> BlastingRecipe<'mc>
impl<'mc> BlastingRecipe<'mc>
pub fn new( jni: &SharedJNIEnv<'mc>, key: impl Into<NamespacedKey<'mc>>, result: impl Into<ItemStack<'mc>>, input: impl Into<RecipeChoice<'mc>>, experience: f32, cooking_time: i32, ) -> Result<BlastingRecipe<'mc>, Box<dyn Error>>
Sourcepub fn set_input(
&self,
input: impl Into<Material<'mc>>,
) -> Result<CookingRecipe<'mc>, Box<dyn Error>>
pub fn set_input( &self, input: impl Into<Material<'mc>>, ) -> Result<CookingRecipe<'mc>, Box<dyn Error>>
Sets the input of this cooking recipe.
Sourcepub fn set_input_choice(
&self,
input: impl Into<RecipeChoice<'mc>>,
) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn set_input_choice( &self, input: impl Into<RecipeChoice<'mc>>, ) -> Result<JObject<'mc>, Box<dyn Error>>
Sets the input of this cooking recipe.
Sourcepub fn input_choice(&self) -> Result<RecipeChoice<'mc>, Box<dyn Error>>
pub fn input_choice(&self) -> Result<RecipeChoice<'mc>, Box<dyn Error>>
Get the input choice.
Sourcepub fn set_experience(&self, experience: f32) -> Result<(), Box<dyn Error>>
pub fn set_experience(&self, experience: f32) -> Result<(), Box<dyn Error>>
Sets the experience given by this recipe.
Sourcepub fn experience(&self) -> Result<f32, Box<dyn Error>>
pub fn experience(&self) -> Result<f32, Box<dyn Error>>
Get the experience given by this recipe.
Sourcepub fn set_cooking_time(&self, cooking_time: i32) -> Result<(), Box<dyn Error>>
pub fn set_cooking_time(&self, cooking_time: i32) -> Result<(), Box<dyn Error>>
Set the cooking time for this recipe in ticks.
Sourcepub fn cooking_time(&self) -> Result<i32, Box<dyn Error>>
pub fn cooking_time(&self) -> Result<i32, Box<dyn Error>>
Get the cooking time for this recipe in ticks.
pub fn key(&self) -> Result<NamespacedKey<'mc>, Box<dyn Error>>
Sourcepub fn group(&self) -> Result<String, Box<dyn Error>>
pub fn group(&self) -> Result<String, Box<dyn Error>>
Get the group of this recipe. Recipes with the same group may be grouped together when displayed in the client.
Sourcepub fn set_group(&self, group: impl Into<String>) -> Result<(), Box<dyn Error>>
pub fn set_group(&self, group: impl Into<String>) -> Result<(), Box<dyn Error>>
Set the group of this recipe. Recipes with the same group may be grouped together when displayed in the client.
Sourcepub fn category(&self) -> Result<CookingBookCategory<'mc>, Box<dyn Error>>
pub fn category(&self) -> Result<CookingBookCategory<'mc>, Box<dyn Error>>
Gets the category which this recipe will appear in the recipe book under. Defaults to {@link CookingBookCategory#MISC} if not set.
Sourcepub fn set_category(
&self,
category: impl Into<CookingBookCategory<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_category( &self, category: impl Into<CookingBookCategory<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the category which this recipe will appear in the recipe book under. Defaults to {@link CookingBookCategory#MISC} if not set.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>