pub struct Chest<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> Chest<'mc>
impl<'mc> Chest<'mc>
Sourcepub fn block_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
pub fn block_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
Gets the inventory of the chest block represented by this block state.
If the chest is a double chest, it returns just the portion of the inventory linked to the half of the chest corresponding to this block state.
If the block was changed to a different type in the meantime, the returned inventory might no longer be valid.
If this block state is not placed this will return the captured inventory snapshot instead.
Sourcepub fn inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
pub fn inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
Gets the inventory of the block represented by this block state.
If the block was changed to a different type in the meantime, the returned inventory might no longer be valid.
If this block state is not placed this will return the captured inventory snapshot instead.
Sourcepub fn snapshot_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
pub fn snapshot_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
Gets the captured inventory snapshot of this container.
The returned inventory is not linked to any block. Any modifications to the returned inventory will not be applied to the block represented by this block state up until {@link #update(boolean, boolean)} has been called.
Sourcepub fn set_loot_table(
&self,
table: impl Into<LootTable<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_loot_table( &self, table: impl Into<LootTable<'mc>>, ) -> Result<(), Box<dyn Error>>
Set the loot table for a container or entity.
To remove a loot table use null. Do not use {@link LootTables#EMPTY} to clear a LootTable.
Sourcepub fn loot_table(&self) -> Result<Option<LootTable<'mc>>, Box<dyn Error>>
pub fn loot_table(&self) -> Result<Option<LootTable<'mc>>, Box<dyn Error>>
Gets the Loot Table attached to this block or entity.
If an block/entity does not have a loot table, this will return null, NOT an empty loot table.
Sourcepub fn set_seed(&self, seed: i64) -> Result<(), Box<dyn Error>>
pub fn set_seed(&self, seed: i64) -> Result<(), Box<dyn Error>>
Set the seed used when this Loot Table generates loot.
Sourcepub fn seed(&self) -> Result<i64, Box<dyn Error>>
pub fn seed(&self) -> Result<i64, Box<dyn Error>>
Get the Loot Table’s seed.
The seed is used when generating loot.
Sourcepub fn open(&self) -> Result<(), Box<dyn Error>>
pub fn open(&self) -> Result<(), Box<dyn Error>>
Sets the block’s animated state to open and prevents it from being closed until {@link #close()} is called.
Sourcepub fn close(&self) -> Result<(), Box<dyn Error>>
pub fn close(&self) -> Result<(), Box<dyn Error>>
Sets the block’s animated state to closed even if a player is currently viewing this block.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>