pub struct Dropper<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> Dropper<'mc>
impl<'mc> Dropper<'mc>
Sourcepub fn drop(&self) -> Result<(), Box<dyn Error>>
pub fn drop(&self) -> Result<(), Box<dyn Error>>
Tries to drop a randomly selected item from the dropper’s inventory, following the normal behavior of a dropper.
Normal behavior of a dropper is as follows:
If the block that the dropper is facing is an InventoryHolder, the randomly selected ItemStack is placed within that Inventory in the first slot that’s available, starting with 0 and counting up.If the inventory is full, nothing happens.
If the block that the dropper is facing is not an InventoryHolder, the randomly selected ItemStack is dropped on the ground in the form of an {@link org.bukkit.entity.Item Item}.
If the block represented by this state is no longer a dropper, this will do nothing.
Sourcepub fn inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
pub fn inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
Gets the inventory of the block represented by this block state.
If the block was changed to a different type in the meantime, the returned inventory might no longer be valid.
If this block state is not placed this will return the captured inventory snapshot instead.
Sourcepub fn snapshot_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
pub fn snapshot_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
Gets the captured inventory snapshot of this container.
The returned inventory is not linked to any block. Any modifications to the returned inventory will not be applied to the block represented by this block state up until {@link #update(boolean, boolean)} has been called.
Sourcepub fn persistent_data_container(
&self,
) -> Result<PersistentDataContainer<'mc>, Box<dyn Error>>
pub fn persistent_data_container( &self, ) -> Result<PersistentDataContainer<'mc>, Box<dyn Error>>
Returns a custom tag container capable of storing tags on the object. Note that the tags stored on this container are all stored under their own custom namespace therefore modifying default tags using this {@link PersistentDataHolder} is impossible.
This {@link PersistentDataHolder} is only linked to the snapshot instance stored by the {@link BlockState}. When storing changes on the {@link PersistentDataHolder}, the updated content will only be applied to the actual tile entity after one of the {@link #update()} methods is called.
Sourcepub fn block(&self) -> Result<Block<'mc>, Box<dyn Error>>
pub fn block(&self) -> Result<Block<'mc>, Box<dyn Error>>
Gets the block associated with this holder.
Sourcepub fn is_locked(&self) -> Result<bool, Box<dyn Error>>
pub fn is_locked(&self) -> Result<bool, Box<dyn Error>>
Checks if the container has a valid (non empty) key.
Sourcepub fn lock(&self) -> Result<String, Box<dyn Error>>
pub fn lock(&self) -> Result<String, Box<dyn Error>>
Gets the key needed to access the container.
Sourcepub fn set_lock(&self, key: impl Into<String>) -> Result<(), Box<dyn Error>>
pub fn set_lock(&self, key: impl Into<String>) -> Result<(), Box<dyn Error>>
Sets the key required to access this container. Set to null (or empty string) to remove key.
Sourcepub fn custom_name(&self) -> Result<Option<String>, Box<dyn Error>>
pub fn custom_name(&self) -> Result<Option<String>, Box<dyn Error>>
Gets the custom name on a mob or block. If there is no name this method will return null.
This value has no effect on players, they will always use their real name.
Sourcepub fn set_custom_name(
&self,
name: impl Into<String>,
) -> Result<(), Box<dyn Error>>
pub fn set_custom_name( &self, name: impl Into<String>, ) -> Result<(), Box<dyn Error>>
Sets a custom name on a mob or block. This name will be used in death messages and can be sent to the client as a nameplate over the mob.
Setting the name to null or an empty string will clear it.
This value has no effect on players, they will always use their real name.
Sourcepub fn set_loot_table(
&self,
table: impl Into<LootTable<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_loot_table( &self, table: impl Into<LootTable<'mc>>, ) -> Result<(), Box<dyn Error>>
Set the loot table for a container or entity.
To remove a loot table use null. Do not use {@link LootTables#EMPTY} to clear a LootTable.
Sourcepub fn loot_table(&self) -> Result<Option<LootTable<'mc>>, Box<dyn Error>>
pub fn loot_table(&self) -> Result<Option<LootTable<'mc>>, Box<dyn Error>>
Gets the Loot Table attached to this block or entity.
If an block/entity does not have a loot table, this will return null, NOT an empty loot table.
Sourcepub fn set_seed(&self, seed: i64) -> Result<(), Box<dyn Error>>
pub fn set_seed(&self, seed: i64) -> Result<(), Box<dyn Error>>
Set the seed used when this Loot Table generates loot.
Sourcepub fn seed(&self) -> Result<i64, Box<dyn Error>>
pub fn seed(&self) -> Result<i64, Box<dyn Error>>
Get the Loot Table’s seed.
The seed is used when generating loot.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>