pub struct Configuration<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> Configuration<'mc>
impl<'mc> Configuration<'mc>
Sourcepub fn add_default(
&self,
path: impl Into<String>,
value: JObject<'mc>,
) -> Result<(), Box<dyn Error>>
pub fn add_default( &self, path: impl Into<String>, value: JObject<'mc>, ) -> Result<(), Box<dyn Error>>
Sets the default value of the given path as provided.
If no source {@link Configuration} was provided as a default collection, then a new {@link MemoryConfiguration} will be created to hold the new default value.
If value is null, the value will be removed from the default Configuration source.
Sourcepub fn add_defaults(
&self,
defaults: impl Into<Configuration<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn add_defaults( &self, defaults: impl Into<Configuration<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the default values of the given paths as provided.
If no source {@link Configuration} was provided as a default collection, then a new {@link MemoryConfiguration} will be created to hold the new default value.
This method will not hold a reference to the specified Configuration, nor will it automatically update if that Configuration ever changes. If you require this, you should set the default source with {@link #setDefaults(org.bukkit.configuration.Configuration)}.
Sourcepub fn set_defaults(
&self,
defaults: impl Into<Configuration<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_defaults( &self, defaults: impl Into<Configuration<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the source of all default values for this {@link Configuration}.
If a previous source was set, or previous default values were defined, then they will not be copied to the new source.
Sourcepub fn defaults(&self) -> Result<Option<Configuration<'mc>>, Box<dyn Error>>
pub fn defaults(&self) -> Result<Option<Configuration<'mc>>, Box<dyn Error>>
Gets the source {@link Configuration} for this configuration.
If no configuration source was set, but default values were added, then a {@link MemoryConfiguration} will be returned. If no source was set and no defaults were set, then this method will return null.
Sourcepub fn options(&self) -> Result<ConfigurationOptions<'mc>, Box<dyn Error>>
pub fn options(&self) -> Result<ConfigurationOptions<'mc>, Box<dyn Error>>
Gets the {@link ConfigurationOptions} for this {@link Configuration}.
All setters through this method are chainable.
Sourcepub fn get_keys(&self, deep: bool) -> Result<JavaSet<'mc>, Box<dyn Error>>
pub fn get_keys(&self, deep: bool) -> Result<JavaSet<'mc>, Box<dyn Error>>
Gets a set containing all keys in this section.
If deep is set to true, then this will contain all the keys within any child {@link ConfigurationSection}s (and their children, etc). These will be in a valid path notation for you to use.
If deep is set to false, then this will contain only the keys of any direct children, and not their own children.
Sourcepub fn get_values(&self, deep: bool) -> Result<JavaMap<'mc>, Box<dyn Error>>
pub fn get_values(&self, deep: bool) -> Result<JavaMap<'mc>, Box<dyn Error>>
Gets a Map containing all keys and their values for this section.
If deep is set to true, then this will contain all the keys and values within any child {@link ConfigurationSection}s (and their children, etc). These keys will be in a valid path notation for you to use.
If deep is set to false, then this will contain only the keys and values of any direct children, and not their own children.
Sourcepub fn contains(
&self,
path: impl Into<String>,
ignore_default: Option<bool>,
) -> Result<bool, Box<dyn Error>>
pub fn contains( &self, path: impl Into<String>, ignore_default: Option<bool>, ) -> Result<bool, Box<dyn Error>>
Checks if this {@link ConfigurationSection} contains the given path.
If the value for the requested path does not exist, the boolean parameter of true has been specified, a default value for the path exists, this will return true.
If a boolean parameter of false has been specified, true will only be returned if there is a set value for the specified path.
Sourcepub fn is_set(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
pub fn is_set(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
Checks if this {@link ConfigurationSection} has a value set for the given path.
If the value for the requested path does not exist but a default value has been specified, this will still return false.
Sourcepub fn current_path(&self) -> Result<Option<String>, Box<dyn Error>>
pub fn current_path(&self) -> Result<Option<String>, Box<dyn Error>>
Gets the path of this {@link ConfigurationSection} from its root {@link Configuration}
For any {@link Configuration} themselves, this will return an empty string.
If the section is no longer contained within its root for any reason, such as being replaced with a different value, this may return null.
To retrieve the single name of this section, that is, the final part of the path returned by this method, you may use {@link #getName()}.
Sourcepub fn name(&self) -> Result<String, Box<dyn Error>>
pub fn name(&self) -> Result<String, Box<dyn Error>>
Gets the name of this individual {@link ConfigurationSection}, in the path.
This will always be the final part of {@link #getCurrentPath()}, unless the section is orphaned.
Sourcepub fn root(&self) -> Result<Option<Configuration<'mc>>, Box<dyn Error>>
pub fn root(&self) -> Result<Option<Configuration<'mc>>, Box<dyn Error>>
Gets the root {@link Configuration} that contains this {@link ConfigurationSection}
For any {@link Configuration} themselves, this will return its own object.
If the section is no longer contained within its root for any reason, such as being replaced with a different value, this may return null.
Sourcepub fn parent(
&self,
) -> Result<Option<ConfigurationSection<'mc>>, Box<dyn Error>>
pub fn parent( &self, ) -> Result<Option<ConfigurationSection<'mc>>, Box<dyn Error>>
Gets the parent {@link ConfigurationSection} that directly contains this {@link ConfigurationSection}.
For any {@link Configuration} themselves, this will return null.
If the section is no longer contained within its parent for any reason, such as being replaced with a different value, this may return null.
Sourcepub fn get(
&self,
path: impl Into<String>,
def: Option<JObject<'mc>>,
) -> Result<Option<JObject<'mc>>, Box<dyn Error>>
pub fn get( &self, path: impl Into<String>, def: Option<JObject<'mc>>, ) -> Result<Option<JObject<'mc>>, Box<dyn Error>>
Gets the requested Object by path, returning a default value if not found.
If the Object does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn set(
&self,
path: impl Into<String>,
value: JObject<'mc>,
) -> Result<(), Box<dyn Error>>
pub fn set( &self, path: impl Into<String>, value: JObject<'mc>, ) -> Result<(), Box<dyn Error>>
Sets the specified path to the given value.
If value is null, the entry will be removed. Any existing entry will be replaced, regardless of what the new value is.
Some implementations may have limitations on what you may store. See their individual javadocs for details. No implementations should allow you to store {@link Configuration}s or {@link ConfigurationSection}s, please use {@link #createSection(java.lang.String)} for that.
Sourcepub fn create_section(
&self,
path: impl Into<String>,
map: Option<impl Into<JavaMap<'mc>>>,
) -> Result<ConfigurationSection<'mc>, Box<dyn Error>>
pub fn create_section( &self, path: impl Into<String>, map: Option<impl Into<JavaMap<'mc>>>, ) -> Result<ConfigurationSection<'mc>, Box<dyn Error>>
Creates a {@link ConfigurationSection} at the specified path, with specified values.
Any value that was previously set at this path will be overwritten. If the previous value was itself a {@link ConfigurationSection}, it will be orphaned.
Sourcepub fn get_string(
&self,
path: impl Into<String>,
def: Option<impl Into<String>>,
) -> Result<Option<String>, Box<dyn Error>>
pub fn get_string( &self, path: impl Into<String>, def: Option<impl Into<String>>, ) -> Result<Option<String>, Box<dyn Error>>
Gets the requested String by path, returning a default value if not found.
If the String does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_string(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
pub fn is_string(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
Checks if the specified path is a String.
If the path exists but is not a String, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a String and return appropriately.
Sourcepub fn get_int(
&self,
path: impl Into<String>,
def: Option<i32>,
) -> Result<i32, Box<dyn Error>>
pub fn get_int( &self, path: impl Into<String>, def: Option<i32>, ) -> Result<i32, Box<dyn Error>>
Gets the requested int by path, returning a default value if not found.
If the int does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_int(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
pub fn is_int(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
Checks if the specified path is an int.
If the path exists but is not a int, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a int and return appropriately.
Sourcepub fn get_boolean(
&self,
path: impl Into<String>,
def: Option<bool>,
) -> Result<bool, Box<dyn Error>>
pub fn get_boolean( &self, path: impl Into<String>, def: Option<bool>, ) -> Result<bool, Box<dyn Error>>
Gets the requested boolean by path, returning a default value if not found.
If the boolean does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_boolean(
&self,
path: impl Into<String>,
) -> Result<bool, Box<dyn Error>>
pub fn is_boolean( &self, path: impl Into<String>, ) -> Result<bool, Box<dyn Error>>
Checks if the specified path is a boolean.
If the path exists but is not a boolean, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a boolean and return appropriately.
Sourcepub fn get_double(
&self,
path: impl Into<String>,
def: Option<f64>,
) -> Result<f64, Box<dyn Error>>
pub fn get_double( &self, path: impl Into<String>, def: Option<f64>, ) -> Result<f64, Box<dyn Error>>
Gets the requested double by path, returning a default value if not found.
If the double does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_double(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
pub fn is_double(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
Checks if the specified path is a double.
If the path exists but is not a double, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a double and return appropriately.
Sourcepub fn get_long(
&self,
path: impl Into<String>,
def: Option<i64>,
) -> Result<i64, Box<dyn Error>>
pub fn get_long( &self, path: impl Into<String>, def: Option<i64>, ) -> Result<i64, Box<dyn Error>>
Gets the requested long by path, returning a default value if not found.
If the long does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_long(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
pub fn is_long(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
Checks if the specified path is a long.
If the path exists but is not a long, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a long and return appropriately.
Sourcepub fn is_list(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
pub fn is_list(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
Checks if the specified path is a List.
If the path exists but is not a List, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a List and return appropriately.
Sourcepub fn get_string_list(
&self,
path: impl Into<String>,
) -> Result<Vec<String>, Box<dyn Error>>
pub fn get_string_list( &self, path: impl Into<String>, ) -> Result<Vec<String>, Box<dyn Error>>
Gets the requested List of String by path.
If the List does not exist but a default value has been specified, this will return the default value. If the List does not exist and no default value was specified, this will return an empty List.
This method will attempt to cast any values into a String if possible, but may miss any values out if they are not compatible.
Sourcepub fn get_object(
&self,
path: impl Into<String>,
clazz: JClass<'mc>,
def: Option<JObject<'mc>>,
) -> Result<Option<JObject<'mc>>, Box<dyn Error>>
pub fn get_object( &self, path: impl Into<String>, clazz: JClass<'mc>, def: Option<JObject<'mc>>, ) -> Result<Option<JObject<'mc>>, Box<dyn Error>>
Gets the requested object at the given path, returning a default value if not found If the Object does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}. Note: For example #getObject(path, String.class, def) is not equivalent to {@link #getString(String, String) #getString(path, def)} because {@link #getString(String, String) #getString(path, def)} converts internally all Objects to Strings. However, #getObject(path, Boolean.class, def) is equivalent to {@link #getBoolean(String, boolean) #getBoolean(path, def)} for example.
Sourcepub fn get_serializable(
&self,
path: impl Into<String>,
clazz: JClass<'mc>,
def: Option<JObject<'mc>>,
) -> Result<Option<JObject<'mc>>, Box<dyn Error>>
pub fn get_serializable( &self, path: impl Into<String>, clazz: JClass<'mc>, def: Option<JObject<'mc>>, ) -> Result<Option<JObject<'mc>>, Box<dyn Error>>
Gets the requested {@link ConfigurationSerializable} object at the given path, returning a default value if not found If the Object does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn get_vector(
&self,
path: impl Into<String>,
def: Option<impl Into<Vector<'mc>>>,
) -> Result<Option<Vector<'mc>>, Box<dyn Error>>
pub fn get_vector( &self, path: impl Into<String>, def: Option<impl Into<Vector<'mc>>>, ) -> Result<Option<Vector<'mc>>, Box<dyn Error>>
Gets the requested {@link Vector} by path, returning a default value if not found.
If the Vector does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_vector(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
pub fn is_vector(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
Checks if the specified path is a Vector.
If the path exists but is not a Vector, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a Vector and return appropriately.
Sourcepub fn get_offline_player(
&self,
path: impl Into<String>,
def: Option<impl Into<OfflinePlayer<'mc>>>,
) -> Result<Option<OfflinePlayer<'mc>>, Box<dyn Error>>
pub fn get_offline_player( &self, path: impl Into<String>, def: Option<impl Into<OfflinePlayer<'mc>>>, ) -> Result<Option<OfflinePlayer<'mc>>, Box<dyn Error>>
Gets the requested {@link OfflinePlayer} by path, returning a default value if not found.
If the OfflinePlayer does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_offline_player(
&self,
path: impl Into<String>,
) -> Result<bool, Box<dyn Error>>
pub fn is_offline_player( &self, path: impl Into<String>, ) -> Result<bool, Box<dyn Error>>
Checks if the specified path is an OfflinePlayer.
If the path exists but is not a OfflinePlayer, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a OfflinePlayer and return appropriately.
Sourcepub fn get_item_stack(
&self,
path: impl Into<String>,
def: Option<impl Into<ItemStack<'mc>>>,
) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>
pub fn get_item_stack( &self, path: impl Into<String>, def: Option<impl Into<ItemStack<'mc>>>, ) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>
Gets the requested {@link ItemStack} by path, returning a default value if not found.
If the ItemStack does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_item_stack(
&self,
path: impl Into<String>,
) -> Result<bool, Box<dyn Error>>
pub fn is_item_stack( &self, path: impl Into<String>, ) -> Result<bool, Box<dyn Error>>
Checks if the specified path is an ItemStack.
If the path exists but is not a ItemStack, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a ItemStack and return appropriately.
Sourcepub fn get_color(
&self,
path: impl Into<String>,
def: Option<impl Into<Color<'mc>>>,
) -> Result<Option<Color<'mc>>, Box<dyn Error>>
pub fn get_color( &self, path: impl Into<String>, def: Option<impl Into<Color<'mc>>>, ) -> Result<Option<Color<'mc>>, Box<dyn Error>>
Gets the requested {@link Color} by path, returning a default value if not found.
If the Color does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_color(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
pub fn is_color(&self, path: impl Into<String>) -> Result<bool, Box<dyn Error>>
Checks if the specified path is a Color.
If the path exists but is not a Color, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a Color and return appropriately.
Sourcepub fn get_location(
&self,
path: impl Into<String>,
def: Option<impl Into<Location<'mc>>>,
) -> Result<Option<Location<'mc>>, Box<dyn Error>>
pub fn get_location( &self, path: impl Into<String>, def: Option<impl Into<Location<'mc>>>, ) -> Result<Option<Location<'mc>>, Box<dyn Error>>
Gets the requested {@link Location} by path, returning a default value if not found.
If the Location does not exist then the specified default value will returned regardless of if a default has been identified in the root {@link Configuration}.
Sourcepub fn is_location(
&self,
path: impl Into<String>,
) -> Result<bool, Box<dyn Error>>
pub fn is_location( &self, path: impl Into<String>, ) -> Result<bool, Box<dyn Error>>
Checks if the specified path is a Location.
If the path exists but is not a Location, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a Location and return appropriately.
Sourcepub fn get_configuration_section(
&self,
path: impl Into<String>,
) -> Result<Option<ConfigurationSection<'mc>>, Box<dyn Error>>
pub fn get_configuration_section( &self, path: impl Into<String>, ) -> Result<Option<ConfigurationSection<'mc>>, Box<dyn Error>>
Gets the requested ConfigurationSection by path.
If the ConfigurationSection does not exist but a default value has been specified, this will return the default value. If the ConfigurationSection does not exist and no default value was specified, this will return null.
Sourcepub fn is_configuration_section(
&self,
path: impl Into<String>,
) -> Result<bool, Box<dyn Error>>
pub fn is_configuration_section( &self, path: impl Into<String>, ) -> Result<bool, Box<dyn Error>>
Checks if the specified path is a ConfigurationSection.
If the path exists but is not a ConfigurationSection, this will return false. If the path does not exist, this will return false. If the path does not exist but a default value has been specified, this will check if that default value is a ConfigurationSection and return appropriately.
Sourcepub fn default_section(
&self,
) -> Result<Option<ConfigurationSection<'mc>>, Box<dyn Error>>
pub fn default_section( &self, ) -> Result<Option<ConfigurationSection<'mc>>, Box<dyn Error>>
Gets the equivalent {@link ConfigurationSection} from the default {@link Configuration} defined in {@link #getRoot()}.
If the root contains no defaults, or the defaults doesn’t contain a value for this path, or the value at this path is not a {@link ConfigurationSection} then this will return null.
Sourcepub fn get_comments(
&self,
path: impl Into<String>,
) -> Result<Vec<String>, Box<dyn Error>>
pub fn get_comments( &self, path: impl Into<String>, ) -> Result<Vec<String>, Box<dyn Error>>
Gets the requested comment list by path.
If no comments exist, an empty list will be returned. A null entry represents an empty line and an empty String represents an empty comment line.
Sourcepub fn get_inline_comments(
&self,
path: impl Into<String>,
) -> Result<Vec<String>, Box<dyn Error>>
pub fn get_inline_comments( &self, path: impl Into<String>, ) -> Result<Vec<String>, Box<dyn Error>>
Gets the requested inline comment list by path.
If no comments exist, an empty list will be returned. A null entry represents an empty line and an empty String represents an empty comment line.
Sourcepub fn set_comments(
&self,
path: impl Into<String>,
comments: Vec<JObject<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_comments( &self, path: impl Into<String>, comments: Vec<JObject<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the comment list at the specified path.
If value is null, the comments will be removed. A null entry is an empty line and an empty String entry is an empty comment line. If the path does not exist, no comments will be set. Any existing comments will be replaced, regardless of what the new comments are.
Some implementations may have limitations on what persists. See their individual javadocs for details.
Sourcepub fn set_inline_comments(
&self,
path: impl Into<String>,
comments: Vec<JObject<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_inline_comments( &self, path: impl Into<String>, comments: Vec<JObject<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the inline comment list at the specified path.
If value is null, the comments will be removed. A null entry is an empty line and an empty String entry is an empty comment line. If the path does not exist, no comment will be set. Any existing comments will be replaced, regardless of what the new comments are.
Some implementations may have limitations on what persists. See their individual javadocs for details.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>