pub struct EntityDamageByBlockEvent<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> EntityDamageByBlockEvent<'mc>
impl<'mc> EntityDamageByBlockEvent<'mc>
pub fn new( jni: &SharedJNIEnv<'mc>, damager: impl Into<Block<'mc>>, damager_state: impl Into<BlockState<'mc>>, damagee: impl Into<Entity<'mc>>, cause: impl Into<EntityDamageEventDamageCause<'mc>>, damage_source: Option<impl Into<DamageSource<'mc>>>, modifiers: Option<impl Into<JavaMap<'mc>>>, modifier_functions: Option<impl Into<JavaMap<'mc>>>, ) -> Result<EntityDamageByBlockEvent<'mc>, Box<dyn Error>>
Sourcepub fn damager(&self) -> Result<Option<Block<'mc>>, Box<dyn Error>>
pub fn damager(&self) -> Result<Option<Block<'mc>>, Box<dyn Error>>
Returns the block that damaged the player.
Sourcepub fn damager_block_state(
&self,
) -> Result<Option<BlockState<'mc>>, Box<dyn Error>>
pub fn damager_block_state( &self, ) -> Result<Option<BlockState<'mc>>, Box<dyn Error>>
Returns the captured BlockState of the block that damaged the player.
pub fn is_cancelled(&self) -> Result<bool, Box<dyn Error>>
pub fn set_cancelled(&self, cancel: bool) -> Result<(), Box<dyn Error>>
Sourcepub fn get_original_damage(
&self,
val_type: impl Into<EntityDamageEventDamageModifier<'mc>>,
) -> Result<f64, Box<dyn Error>>
pub fn get_original_damage( &self, val_type: impl Into<EntityDamageEventDamageModifier<'mc>>, ) -> Result<f64, Box<dyn Error>>
Gets the original damage for the specified modifier, as defined at this event’s construction.
Sourcepub fn set_damage(
&self,
val_type: impl Into<EntityDamageEventDamageModifier<'mc>>,
damage: Option<f64>,
) -> Result<(), Box<dyn Error>>
pub fn set_damage( &self, val_type: impl Into<EntityDamageEventDamageModifier<'mc>>, damage: Option<f64>, ) -> Result<(), Box<dyn Error>>
Sets the damage for the specified modifier.
Sourcepub fn damage(&self) -> Result<f64, Box<dyn Error>>
pub fn damage(&self) -> Result<f64, Box<dyn Error>>
Gets the raw amount of damage caused by the event
Sourcepub fn is_applicable(
&self,
val_type: impl Into<EntityDamageEventDamageModifier<'mc>>,
) -> Result<bool, Box<dyn Error>>
pub fn is_applicable( &self, val_type: impl Into<EntityDamageEventDamageModifier<'mc>>, ) -> Result<bool, Box<dyn Error>>
This checks to see if a particular modifier is valid for this event’s caller, such that, {@link #setDamage(DamageModifier, double)} will not throw an {@link UnsupportedOperationException}.
{@link DamageModifier#BASE} is always applicable.
Sourcepub fn final_damage(&self) -> Result<f64, Box<dyn Error>>
pub fn final_damage(&self) -> Result<f64, Box<dyn Error>>
Gets the amount of damage caused by the event after all damage reduction is applied.
Sourcepub fn cause(&self) -> Result<EntityDamageEventDamageCause<'mc>, Box<dyn Error>>
pub fn cause(&self) -> Result<EntityDamageEventDamageCause<'mc>, Box<dyn Error>>
Gets the cause of the damage.
While a DamageCause may indicate a specific Bukkit-assigned cause of damage, {@link #getDamageSource()} may expose additional types of damage such as custom damage types provided by data packs, as well as any direct or indirect entities, locations, or other contributing factors to the damage being inflicted. The alternative is generally preferred, but DamageCauses provided to this event should largely encompass most common use cases for developers if a simple cause is required.
Sourcepub fn damage_source(&self) -> Result<DamageSource<'mc>, Box<dyn Error>>
pub fn damage_source(&self) -> Result<DamageSource<'mc>, Box<dyn Error>>
Get the source of damage.
pub fn handlers(&self) -> Result<HandlerList<'mc>, Box<dyn Error>>
pub fn handler_list( jni: &SharedJNIEnv<'mc>, ) -> Result<HandlerList<'mc>, Box<dyn Error>>
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>