pub struct TropicalFishBucketMeta<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> TropicalFishBucketMeta<'mc>
impl<'mc> TropicalFishBucketMeta<'mc>
Sourcepub fn pattern_color(&self) -> Result<DyeColor<'mc>, Box<dyn Error>>
pub fn pattern_color(&self) -> Result<DyeColor<'mc>, Box<dyn Error>>
Gets the color of the fish’s pattern.
Plugins should check that hasVariant() returns true before
calling this method.
Sourcepub fn set_pattern_color(
&self,
color: impl Into<DyeColor<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_pattern_color( &self, color: impl Into<DyeColor<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the color of the fish’s pattern.
Setting this when hasVariant() returns false will initialize
all other values to unspecified defaults.
Sourcepub fn body_color(&self) -> Result<DyeColor<'mc>, Box<dyn Error>>
pub fn body_color(&self) -> Result<DyeColor<'mc>, Box<dyn Error>>
Gets the color of the fish’s body.
Plugins should check that hasVariant() returns true before
calling this method.
Sourcepub fn set_body_color(
&self,
color: impl Into<DyeColor<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_body_color( &self, color: impl Into<DyeColor<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the color of the fish’s body.
Setting this when hasVariant() returns false will initialize
all other values to unspecified defaults.
Sourcepub fn pattern(&self) -> Result<TropicalFishPattern<'mc>, Box<dyn Error>>
pub fn pattern(&self) -> Result<TropicalFishPattern<'mc>, Box<dyn Error>>
Gets the fish’s pattern.
Plugins should check that hasVariant() returns true before
calling this method.
Sourcepub fn set_pattern(
&self,
pattern: impl Into<TropicalFishPattern<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_pattern( &self, pattern: impl Into<TropicalFishPattern<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the fish’s pattern.
Setting this when hasVariant() returns false will initialize
all other values to unspecified defaults.
Sourcepub fn has_variant(&self) -> Result<bool, Box<dyn Error>>
pub fn has_variant(&self) -> Result<bool, Box<dyn Error>>
Checks for existence of a variant tag indicating a specific fish will be spawned.
pub fn clone(&self) -> Result<TropicalFishBucketMeta<'mc>, Box<dyn Error>>
Sourcepub fn has_display_name(&self) -> Result<bool, Box<dyn Error>>
pub fn has_display_name(&self) -> Result<bool, Box<dyn Error>>
Checks for existence of a display name.
Sourcepub fn display_name(&self) -> Result<String, Box<dyn Error>>
pub fn display_name(&self) -> Result<String, Box<dyn Error>>
Gets the display name that is set.
Plugins should check that hasDisplayName() returns true
before calling this method.
Sourcepub fn set_display_name(
&self,
name: impl Into<String>,
) -> Result<(), Box<dyn Error>>
pub fn set_display_name( &self, name: impl Into<String>, ) -> Result<(), Box<dyn Error>>
Sets the display name.
Sourcepub fn has_item_name(&self) -> Result<bool, Box<dyn Error>>
pub fn has_item_name(&self) -> Result<bool, Box<dyn Error>>
Checks for existence of an item name.
Item name differs from display name in that it is cannot be edited by an anvil, is not styled with italics, and does not show labels.
Sourcepub fn item_name(&self) -> Result<String, Box<dyn Error>>
pub fn item_name(&self) -> Result<String, Box<dyn Error>>
Gets the item name that is set.
Item name differs from display name in that it is cannot be edited by an anvil, is not styled with italics, and does not show labels.
Plugins should check that hasItemName() returns true before
calling this method.
Sourcepub fn set_item_name(
&self,
name: impl Into<String>,
) -> Result<(), Box<dyn Error>>
pub fn set_item_name( &self, name: impl Into<String>, ) -> Result<(), Box<dyn Error>>
Sets the item name.
Item name differs from display name in that it is cannot be edited by an anvil, is not styled with italics, and does not show labels.
Sourcepub fn has_localized_name(&self) -> Result<bool, Box<dyn Error>>
👎Deprecated
pub fn has_localized_name(&self) -> Result<bool, Box<dyn Error>>
Checks for existence of a localized name.
Sourcepub fn localized_name(&self) -> Result<String, Box<dyn Error>>
👎Deprecated
pub fn localized_name(&self) -> Result<String, Box<dyn Error>>
Gets the localized display name that is set.Plugins should check that hasLocalizedName() returns true before calling this method.
Sourcepub fn set_localized_name(
&self,
name: impl Into<String>,
) -> Result<(), Box<dyn Error>>
👎Deprecated
pub fn set_localized_name( &self, name: impl Into<String>, ) -> Result<(), Box<dyn Error>>
Sets the localized name.
Sourcepub fn lore(&self) -> Result<Option<Vec<String>>, Box<dyn Error>>
pub fn lore(&self) -> Result<Option<Vec<String>>, Box<dyn Error>>
Gets the lore that is set.
Plugins should check if hasLore() returns true before
calling this method.
Sourcepub fn set_lore(&self, lore: Vec<JObject<'mc>>) -> Result<(), Box<dyn Error>>
pub fn set_lore(&self, lore: Vec<JObject<'mc>>) -> Result<(), Box<dyn Error>>
Sets the lore for this item. Removes lore when given null.
Sourcepub fn has_custom_model_data(&self) -> Result<bool, Box<dyn Error>>
pub fn has_custom_model_data(&self) -> Result<bool, Box<dyn Error>>
Checks for existence of custom model data.
CustomModelData is an integer that may be associated client side with a custom item model.
Sourcepub fn custom_model_data(&self) -> Result<i32, Box<dyn Error>>
pub fn custom_model_data(&self) -> Result<i32, Box<dyn Error>>
Gets the custom model data that is set.
CustomModelData is an integer that may be associated client side with a custom item model.
Plugins should check that hasCustomModelData() returns true
before calling this method.
Sourcepub fn set_custom_model_data(&self, data: i32) -> Result<(), Box<dyn Error>>
pub fn set_custom_model_data(&self, data: i32) -> Result<(), Box<dyn Error>>
Sets the custom model data.
CustomModelData is an integer that may be associated client side with a custom item model.
Sourcepub fn has_enchants(&self) -> Result<bool, Box<dyn Error>>
pub fn has_enchants(&self) -> Result<bool, Box<dyn Error>>
Checks for the existence of any enchantments.
Sourcepub fn has_enchant(
&self,
ench: impl Into<Enchantment<'mc>>,
) -> Result<bool, Box<dyn Error>>
pub fn has_enchant( &self, ench: impl Into<Enchantment<'mc>>, ) -> Result<bool, Box<dyn Error>>
Checks for existence of the specified enchantment.
Sourcepub fn get_enchant_level(
&self,
ench: impl Into<Enchantment<'mc>>,
) -> Result<i32, Box<dyn Error>>
pub fn get_enchant_level( &self, ench: impl Into<Enchantment<'mc>>, ) -> Result<i32, Box<dyn Error>>
Checks for the level of the specified enchantment.
Sourcepub fn enchants(&self) -> Result<JavaMap<'mc>, Box<dyn Error>>
pub fn enchants(&self) -> Result<JavaMap<'mc>, Box<dyn Error>>
Returns a copy the enchantments in this ItemMeta.
Returns an empty map if none.
Sourcepub fn add_enchant(
&self,
ench: impl Into<Enchantment<'mc>>,
level: i32,
ignore_level_restriction: bool,
) -> Result<bool, Box<dyn Error>>
pub fn add_enchant( &self, ench: impl Into<Enchantment<'mc>>, level: i32, ignore_level_restriction: bool, ) -> Result<bool, Box<dyn Error>>
Adds the specified enchantment to this item meta.
Sourcepub fn remove_enchant(
&self,
ench: impl Into<Enchantment<'mc>>,
) -> Result<bool, Box<dyn Error>>
pub fn remove_enchant( &self, ench: impl Into<Enchantment<'mc>>, ) -> Result<bool, Box<dyn Error>>
Removes the specified enchantment from this item meta.
Sourcepub fn remove_enchantments(&self) -> Result<(), Box<dyn Error>>
pub fn remove_enchantments(&self) -> Result<(), Box<dyn Error>>
Removes all enchantments from this item meta.
Sourcepub fn has_conflicting_enchant(
&self,
ench: impl Into<Enchantment<'mc>>,
) -> Result<bool, Box<dyn Error>>
pub fn has_conflicting_enchant( &self, ench: impl Into<Enchantment<'mc>>, ) -> Result<bool, Box<dyn Error>>
Checks if the specified enchantment conflicts with any enchantments in this ItemMeta.
Sourcepub fn add_item_flags(
&self,
item_flags: impl Into<ItemFlag<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn add_item_flags( &self, item_flags: impl Into<ItemFlag<'mc>>, ) -> Result<(), Box<dyn Error>>
Set itemflags which should be ignored when rendering a ItemStack in the Client. This Method does silently ignore double set itemFlags.
Sourcepub fn remove_item_flags(
&self,
item_flags: impl Into<ItemFlag<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn remove_item_flags( &self, item_flags: impl Into<ItemFlag<'mc>>, ) -> Result<(), Box<dyn Error>>
Remove specific set of itemFlags. This tells the Client it should render it again. This Method does silently ignore double removed itemFlags.
Sourcepub fn item_flags(&self) -> Result<JavaSet<'mc>, Box<dyn Error>>
pub fn item_flags(&self) -> Result<JavaSet<'mc>, Box<dyn Error>>
Get current set itemFlags. The collection returned is unmodifiable.
Sourcepub fn has_item_flag(
&self,
flag: impl Into<ItemFlag<'mc>>,
) -> Result<bool, Box<dyn Error>>
pub fn has_item_flag( &self, flag: impl Into<ItemFlag<'mc>>, ) -> Result<bool, Box<dyn Error>>
Check if the specified flag is present on this item.
Sourcepub fn is_hide_tooltip(&self) -> Result<bool, Box<dyn Error>>
pub fn is_hide_tooltip(&self) -> Result<bool, Box<dyn Error>>
Gets if this item has hide_tooltip set. An item with this set will not show any tooltip whatsoever.
Sourcepub fn set_hide_tooltip(&self, hide_tooltip: bool) -> Result<(), Box<dyn Error>>
pub fn set_hide_tooltip(&self, hide_tooltip: bool) -> Result<(), Box<dyn Error>>
Sets if this item has hide_tooltip set. An item with this set will not show any tooltip whatsoever.
Sourcepub fn is_unbreakable(&self) -> Result<bool, Box<dyn Error>>
pub fn is_unbreakable(&self) -> Result<bool, Box<dyn Error>>
Return if the unbreakable tag is true. An unbreakable item will not lose durability.
Sourcepub fn set_unbreakable(&self, unbreakable: bool) -> Result<(), Box<dyn Error>>
pub fn set_unbreakable(&self, unbreakable: bool) -> Result<(), Box<dyn Error>>
Sets the unbreakable tag. An unbreakable item will not lose durability.
Sourcepub fn has_enchantment_glint_override(&self) -> Result<bool, Box<dyn Error>>
pub fn has_enchantment_glint_override(&self) -> Result<bool, Box<dyn Error>>
Gets if an enchantment_glint_override is set.
Sourcepub fn enchantment_glint_override(&self) -> Result<bool, Box<dyn Error>>
pub fn enchantment_glint_override(&self) -> Result<bool, Box<dyn Error>>
Sets the enchantment_glint_override. If true, the item will glint, even without enchantments; if false, the item will not glint, even with enchantments. Plugins should check {@link #hasEnchantmentGlintOverride()} before calling this method.
Sourcepub fn set_enchantment_glint_override(
&self,
val_override: bool,
) -> Result<(), Box<dyn Error>>
pub fn set_enchantment_glint_override( &self, val_override: bool, ) -> Result<(), Box<dyn Error>>
Sets the enchantment_glint_override. If true, the item will glint, even without enchantments; if false, the item will not glint, even with enchantments. If null, the override will be cleared.
Sourcepub fn is_fire_resistant(&self) -> Result<bool, Box<dyn Error>>
pub fn is_fire_resistant(&self) -> Result<bool, Box<dyn Error>>
Checks if this item is fire_resistant. If true, it will not burn in fire or lava.
Sourcepub fn set_fire_resistant(
&self,
fire_resistant: bool,
) -> Result<(), Box<dyn Error>>
pub fn set_fire_resistant( &self, fire_resistant: bool, ) -> Result<(), Box<dyn Error>>
Sets if this item is fire_resistant. If true, it will not burn in fire or lava.
Sourcepub fn has_max_stack_size(&self) -> Result<bool, Box<dyn Error>>
pub fn has_max_stack_size(&self) -> Result<bool, Box<dyn Error>>
Gets if the max_stack_size is set.
Sourcepub fn max_stack_size(&self) -> Result<i32, Box<dyn Error>>
pub fn max_stack_size(&self) -> Result<i32, Box<dyn Error>>
Gets the max_stack_size. This is the maximum amount which an item will stack.
Sourcepub fn set_max_stack_size(&self, max: i32) -> Result<(), Box<dyn Error>>
pub fn set_max_stack_size(&self, max: i32) -> Result<(), Box<dyn Error>>
Sets the max_stack_size. This is the maximum amount which an item will stack.
Sourcepub fn rarity(&self) -> Result<ItemRarity<'mc>, Box<dyn Error>>
pub fn rarity(&self) -> Result<ItemRarity<'mc>, Box<dyn Error>>
Gets the item rarity. Plugins should check {@link #hasRarity()} before calling this method.
Sourcepub fn set_rarity(
&self,
rarity: impl Into<ItemRarity<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_rarity( &self, rarity: impl Into<ItemRarity<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the item rarity.
Sourcepub fn food(&self) -> Result<FoodComponent<'mc>, Box<dyn Error>>
pub fn food(&self) -> Result<FoodComponent<'mc>, Box<dyn Error>>
Gets the food set on this item, or creates an empty food instance.
The returned component is a snapshot of its current state and does not reflect a live view of what is on an item. After changing any value on this component, it must be set with {@link #setFood(FoodComponent)} to apply the changes.
Sourcepub fn set_food(
&self,
food: impl Into<FoodComponent<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_food( &self, food: impl Into<FoodComponent<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the item food.
Sourcepub fn tool(&self) -> Result<ToolComponent<'mc>, Box<dyn Error>>
pub fn tool(&self) -> Result<ToolComponent<'mc>, Box<dyn Error>>
Gets the tool set on this item, or creates an empty tool instance.
The returned component is a snapshot of its current state and does not reflect a live view of what is on an item. After changing any value on this component, it must be set with {@link #setTool(ToolComponent)} to apply the changes.
Sourcepub fn set_tool(
&self,
tool: impl Into<ToolComponent<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_tool( &self, tool: impl Into<ToolComponent<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the item tool.
Sourcepub fn has_jukebox_playable(&self) -> Result<bool, Box<dyn Error>>
pub fn has_jukebox_playable(&self) -> Result<bool, Box<dyn Error>>
Checks if the jukebox playable is set.
Sourcepub fn jukebox_playable(
&self,
) -> Result<Option<JukeboxPlayableComponent<'mc>>, Box<dyn Error>>
pub fn jukebox_playable( &self, ) -> Result<Option<JukeboxPlayableComponent<'mc>>, Box<dyn Error>>
Gets the jukebox playable component set on this item.
The returned component is a snapshot of its current state and does not reflect a live view of what is on an item. After changing any value on this component, it must be set with {@link #setJukeboxPlayable(org.bukkit.inventory.meta.components.JukeboxComponent)} to apply the changes.
Sourcepub fn set_jukebox_playable(
&self,
jukebox_playable: impl Into<JukeboxPlayableComponent<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_jukebox_playable( &self, jukebox_playable: impl Into<JukeboxPlayableComponent<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the item tool.
Sourcepub fn has_attribute_modifiers(&self) -> Result<bool, Box<dyn Error>>
pub fn has_attribute_modifiers(&self) -> Result<bool, Box<dyn Error>>
Checks for the existence of any AttributeModifiers.
Sourcepub fn get_attribute_modifiers(
&self,
attribute: impl Into<Attribute<'mc>>,
) -> Result<Option<Vec<AttributeModifier<'mc>>>, Box<dyn Error>>
pub fn get_attribute_modifiers( &self, attribute: impl Into<Attribute<'mc>>, ) -> Result<Option<Vec<AttributeModifier<'mc>>>, Box<dyn Error>>
Return an immutable copy of all {@link AttributeModifier}s for a given {@link Attribute}
Sourcepub fn add_attribute_modifier(
&self,
attribute: impl Into<Attribute<'mc>>,
modifier: impl Into<AttributeModifier<'mc>>,
) -> Result<bool, Box<dyn Error>>
pub fn add_attribute_modifier( &self, attribute: impl Into<Attribute<'mc>>, modifier: impl Into<AttributeModifier<'mc>>, ) -> Result<bool, Box<dyn Error>>
Add an Attribute and it’s Modifier. AttributeModifiers can now support {@link EquipmentSlot}s. If not set, the {@link AttributeModifier} will be active in ALL slots.
Two {@link AttributeModifier}s that have the same {@link java.util.UUID} cannot exist on the same Attribute.
Sourcepub fn set_attribute_modifiers(
&self,
attribute_modifiers: JObject<'mc>,
) -> Result<(), Box<dyn Error>>
pub fn set_attribute_modifiers( &self, attribute_modifiers: JObject<'mc>, ) -> Result<(), Box<dyn Error>>
Set all {@link Attribute}s and their {@link AttributeModifier}s. To clear all currently set Attributes and AttributeModifiers use null or an empty Multimap. If not null nor empty, this will filter all entries that are not-null and add them to the ItemStack.
Sourcepub fn remove_attribute_modifier(
&self,
attribute: impl Into<Attribute<'mc>>,
modifier: Option<impl Into<AttributeModifier<'mc>>>,
) -> Result<bool, Box<dyn Error>>
pub fn remove_attribute_modifier( &self, attribute: impl Into<Attribute<'mc>>, modifier: Option<impl Into<AttributeModifier<'mc>>>, ) -> Result<bool, Box<dyn Error>>
Remove a specific {@link Attribute} and {@link AttributeModifier}. AttributeModifiers are matched according to their {@link java.util.UUID}.
Sourcepub fn as_string(&self) -> Result<String, Box<dyn Error>>
pub fn as_string(&self) -> Result<String, Box<dyn Error>>
Get this ItemMeta as an NBT string. If this ItemMeta does not have any NBT, then {@code “{}”} will be returned.
This string should NEVER be relied upon as a serializable value. If serialization is desired, the {@link ConfigurationSerializable} API should be used instead.
Sourcepub fn as_component_string(&self) -> Result<String, Box<dyn Error>>
pub fn as_component_string(&self) -> Result<String, Box<dyn Error>>
Get this ItemMeta as a component-compliant string. If this ItemMeta does not contain any components, then {@code “[]”} will be returned.
The result of this method should yield a string representing the components altered by this ItemMeta instance. When passed to {@link ItemFactory#createItemStack(String)} with a prepended item type, it will create an ItemStack that has an ItemMeta matching this ItemMeta instance exactly. Note that this method returns ONLY the components and cannot be passed to createItemStack() alone. An example may look something like this:
ItemStack itemStack = // ... an item stack obtained from somewhere ItemMeta itemMeta = itemStack.getItemMeta(); String components = itemMeta.getAsComponentString(); // example: "[minecraft:damage=53]" String itemTypeKey = itemStack.getType().getKey().toString(); // example: "minecraft:diamond_sword" String itemAsString = itemTypeKey + components; // results in: "minecraft:diamond_sword[minecraft:damage=53]" ItemStack recreatedItemStack = Bukkit.getItemFactory().createItemStack(itemAsString); assert itemStack.isSimilar(recreatedItemStack); // Should be true*
*Components not represented or explicitly overridden by this ItemMeta instance will not be included in the resulting string and therefore may result in ItemStacks that do not match exactly. For example, if {@link #setDisplayName(String)} is not set, then the custom name component will not be included. Or if this ItemMeta is a PotionMeta, it will not include any components related to lodestone compasses, banners, or books, etc., only components modifiable by a PotionMeta instance.
This string should NEVER be relied upon as a serializable value. If serialization is desired, the {@link ConfigurationSerializable} API should be used instead.
Sourcepub fn custom_tag_container(
&self,
) -> Result<CustomItemTagContainer<'mc>, Box<dyn Error>>
👎Deprecated
pub fn custom_tag_container( &self, ) -> Result<CustomItemTagContainer<'mc>, Box<dyn Error>>
Returns a public custom tag container capable of storing tags on the item. Those tags will be sent to the client with all of their content, so the client is capable of reading them. This will result in the player seeing a NBT Tag notification on the item. These tags can also be modified by the client once in creative mode
Sourcepub fn set_version(&self, version: i32) -> Result<(), Box<dyn Error>>
pub fn set_version(&self, version: i32) -> Result<(), Box<dyn Error>>
Internal use only! Do not use under any circumstances!
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>