pub struct CrafterInventory<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> CrafterInventory<'mc>
impl<'mc> CrafterInventory<'mc>
Sourcepub fn max_stack_size(&self) -> Result<i32, Box<dyn Error>>
pub fn max_stack_size(&self) -> Result<i32, Box<dyn Error>>
Returns the maximum stack size for an ItemStack in this inventory.
Sourcepub fn set_max_stack_size(&self, size: i32) -> Result<(), Box<dyn Error>>
pub fn set_max_stack_size(&self, size: i32) -> Result<(), Box<dyn Error>>
This method allows you to change the maximum stack size for an inventory.
Caveats:
- Not all inventories respect this value.
- Stacks larger than 127 may be clipped when the world is saved.
- This value is not guaranteed to be preserved; be sure to set it before every time you want to set a slot over the max stack size.
- Stacks larger than the default max size for this type of inventory may not display correctly in the client.
Sourcepub fn get_item(
&self,
index: i32,
) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>
pub fn get_item( &self, index: i32, ) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>
Returns the ItemStack found in the slot at the given index
Sourcepub fn set_item(
&self,
index: i32,
item: Option<impl Into<ItemStack<'mc>>>,
) -> Result<(), Box<dyn Error>>
pub fn set_item( &self, index: i32, item: Option<impl Into<ItemStack<'mc>>>, ) -> Result<(), Box<dyn Error>>
Stores the ItemStack at the given index of the inventory.
Sourcepub fn add_item(
&self,
items: impl Into<ItemStack<'mc>>,
) -> Result<JavaHashMap<'mc>, Box<dyn Error>>
pub fn add_item( &self, items: impl Into<ItemStack<'mc>>, ) -> Result<JavaHashMap<'mc>, Box<dyn Error>>
Stores the given ItemStacks in the inventory. This will try to fill existing stacks and empty slots as well as it can.
The returned HashMap contains what it couldn’t store, where the key is the index of the parameter, and the value is the ItemStack at that index of the varargs parameter. If all items are stored, it will return an empty HashMap.
If you pass in ItemStacks which exceed the maximum stack size for the Material, first they will be added to partial stacks where Material.getMaxStackSize() is not exceeded, up to Material.getMaxStackSize(). When there are no partial stacks left stacks will be split on Inventory.getMaxStackSize() allowing you to exceed the maximum stack size for that material.
It is known that in some implementations this method will also set the inputted argument amount to the number of that item not placed in slots.
Sourcepub fn remove_item(
&self,
items: impl Into<ItemStack<'mc>>,
) -> Result<JavaHashMap<'mc>, Box<dyn Error>>
pub fn remove_item( &self, items: impl Into<ItemStack<'mc>>, ) -> Result<JavaHashMap<'mc>, Box<dyn Error>>
Removes the given ItemStacks from the inventory.
It will try to remove ‘as much as possible’ from the types and amounts you give as arguments.
The returned HashMap contains what it couldn’t remove, where the key is the index of the parameter, and the value is the ItemStack at that index of the varargs parameter. If all the given ItemStacks are removed, it will return an empty HashMap.
It is known that in some implementations this method will also set the inputted argument amount to the number of that item not removed from slots.
Sourcepub fn contents(&self) -> Result<ItemStack<'mc>, Box<dyn Error>>
pub fn contents(&self) -> Result<ItemStack<'mc>, Box<dyn Error>>
Returns all ItemStacks from the inventory
Sourcepub fn set_contents(
&self,
items: impl Into<ItemStack<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_contents( &self, items: impl Into<ItemStack<'mc>>, ) -> Result<(), Box<dyn Error>>
Completely replaces the inventory’s contents. Removes all existing contents and replaces it with the ItemStacks given in the array.
Sourcepub fn storage_contents(&self) -> Result<ItemStack<'mc>, Box<dyn Error>>
pub fn storage_contents(&self) -> Result<ItemStack<'mc>, Box<dyn Error>>
Return the contents from the section of the inventory where items can reasonably be expected to be stored. In most cases this will represent the entire inventory, but in some cases it may exclude armor or result slots.
It is these contents which will be used for add / contains / remove methods which look for a specific stack.
Sourcepub fn set_storage_contents(
&self,
items: impl Into<ItemStack<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_storage_contents( &self, items: impl Into<ItemStack<'mc>>, ) -> Result<(), Box<dyn Error>>
Put the given ItemStacks into the storage slots
Sourcepub fn contains(
&self,
material: impl Into<Material<'mc>>,
amount: Option<i32>,
) -> Result<bool, Box<dyn Error>>
pub fn contains( &self, material: impl Into<Material<'mc>>, amount: Option<i32>, ) -> Result<bool, Box<dyn Error>>
Checks if the inventory contains any ItemStacks with the given material, adding to at least the minimum amount specified.
Sourcepub fn contains_at_least(
&self,
item: impl Into<ItemStack<'mc>>,
amount: i32,
) -> Result<bool, Box<dyn Error>>
pub fn contains_at_least( &self, item: impl Into<ItemStack<'mc>>, amount: i32, ) -> Result<bool, Box<dyn Error>>
Checks if the inventory contains ItemStacks matching the given ItemStack whose amounts sum to at least the minimum amount specified.
Sourcepub fn all(
&self,
item: impl Into<ItemStack<'mc>>,
) -> Result<JavaHashMap<'mc>, Box<dyn Error>>
pub fn all( &self, item: impl Into<ItemStack<'mc>>, ) -> Result<JavaHashMap<'mc>, Box<dyn Error>>
Finds all slots in the inventory containing any ItemStacks with the given ItemStack. This will only match slots if both the type and the amount of the stack match
The HashMap contains entries where, the key is the slot index, and the value is the ItemStack in that slot. If no matching ItemStack with the given Material is found, an empty map is returned.
Sourcepub fn first(
&self,
item: impl Into<ItemStack<'mc>>,
) -> Result<i32, Box<dyn Error>>
pub fn first( &self, item: impl Into<ItemStack<'mc>>, ) -> Result<i32, Box<dyn Error>>
Returns the first slot in the inventory containing an ItemStack with the given stack. This will only match a slot if both the type and the amount of the stack match
Sourcepub fn is_empty(&self) -> Result<bool, Box<dyn Error>>
pub fn is_empty(&self) -> Result<bool, Box<dyn Error>>
Check whether or not this inventory is empty. An inventory is considered to be empty if there are no ItemStacks in any slot of this inventory.
Sourcepub fn remove(
&self,
item: impl Into<ItemStack<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn remove( &self, item: impl Into<ItemStack<'mc>>, ) -> Result<(), Box<dyn Error>>
Removes all stacks in the inventory matching the given stack.
This will only match a slot if both the type and the amount of the stack match
Sourcepub fn clear(&self, index: Option<i32>) -> Result<(), Box<dyn Error>>
pub fn clear(&self, index: Option<i32>) -> Result<(), Box<dyn Error>>
Clears out a particular slot in the index.
Sourcepub fn viewers(&self) -> Result<Vec<HumanEntity<'mc>>, Box<dyn Error>>
pub fn viewers(&self) -> Result<Vec<HumanEntity<'mc>>, Box<dyn Error>>
Gets a list of players viewing the inventory. Note that a player is considered to be viewing their own inventory and internal crafting screen even when said inventory is not open. They will normally be considered to be viewing their inventory even when they have a different inventory screen open, but it’s possible for customized inventory screens to exclude the viewer’s inventory, so this should never be assumed to be non-empty.
Sourcepub fn get_type(&self) -> Result<InventoryType<'mc>, Box<dyn Error>>
pub fn get_type(&self) -> Result<InventoryType<'mc>, Box<dyn Error>>
Returns what type of inventory this is.
Sourcepub fn holder(&self) -> Result<Option<InventoryHolder<'mc>>, Box<dyn Error>>
pub fn holder(&self) -> Result<Option<InventoryHolder<'mc>>, Box<dyn Error>>
Gets the block or entity belonging to the open inventory
pub fn iterator(&self) -> Result<JavaListIterator<'mc>, Box<dyn Error>>
Sourcepub fn location(&self) -> Result<Option<Location<'mc>>, Box<dyn Error>>
pub fn location(&self) -> Result<Option<Location<'mc>>, Box<dyn Error>>
Get the location of the block or entity which corresponds to this inventory. May return null if this container was custom created or is a virtual / subcontainer.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>