pub struct CrafterView<'mc>(/* private fields */);Implementations
Sourceimpl<'mc> CrafterView<'mc>
impl<'mc> CrafterView<'mc>
Sourcepub fn is_slot_disabled(&self, slot: i32) -> Result<bool, Box<dyn Error>>
pub fn is_slot_disabled(&self, slot: i32) -> Result<bool, Box<dyn Error>>
Checks if the given crafter slot is disabled.
Sourcepub fn is_powered(&self) -> Result<bool, Box<dyn Error>>
pub fn is_powered(&self) -> Result<bool, Box<dyn Error>>
Checks whether or not this crafter view is powered.
Sourcepub fn set_slot_disabled(
&self,
slot: i32,
disabled: bool,
) -> Result<(), Box<dyn Error>>
pub fn set_slot_disabled( &self, slot: i32, disabled: bool, ) -> Result<(), Box<dyn Error>>
Sets the status of the crafter slot.
Sourcepub fn top_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
pub fn top_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
Get the upper inventory involved in this transaction.
Sourcepub fn bottom_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
pub fn bottom_inventory(&self) -> Result<Inventory<'mc>, Box<dyn Error>>
Get the lower inventory involved in this transaction.
Sourcepub fn get_type(&self) -> Result<InventoryType<'mc>, Box<dyn Error>>
pub fn get_type(&self) -> Result<InventoryType<'mc>, Box<dyn Error>>
Determine the type of inventory involved in the transaction. This indicates the window style being shown. It will never return PLAYER, since that is common to all windows.
Sourcepub fn set_item(
&self,
slot: i32,
item: impl Into<ItemStack<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_item( &self, slot: i32, item: impl Into<ItemStack<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets one item in this inventory view by its raw slot ID.
Note: If slot ID -999 is chosen, it may be expected that the item is dropped on the ground. This is not required behaviour, however.
Sourcepub fn get_item(
&self,
slot: i32,
) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>
pub fn get_item( &self, slot: i32, ) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>
Gets one item in this inventory view by its raw slot ID.
Sourcepub fn set_cursor(
&self,
item: impl Into<ItemStack<'mc>>,
) -> Result<(), Box<dyn Error>>
pub fn set_cursor( &self, item: impl Into<ItemStack<'mc>>, ) -> Result<(), Box<dyn Error>>
Sets the item on the cursor of one of the viewing players.
Sourcepub fn cursor(&self) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>
pub fn cursor(&self) -> Result<Option<ItemStack<'mc>>, Box<dyn Error>>
Get the item on the cursor of one of the viewing players.
Sourcepub fn get_inventory(
&self,
raw_slot: i32,
) -> Result<Option<Inventory<'mc>>, Box<dyn Error>>
pub fn get_inventory( &self, raw_slot: i32, ) -> Result<Option<Inventory<'mc>>, Box<dyn Error>>
Gets the inventory corresponding to the given raw slot ID. If the slot ID is {@link #OUTSIDE} null will be returned, otherwise behaviour for illegal and negative slot IDs is undefined. May be used with {@link #convertSlot(int)} to directly index an underlying inventory.
Sourcepub fn convert_slot(&self, raw_slot: i32) -> Result<i32, Box<dyn Error>>
pub fn convert_slot(&self, raw_slot: i32) -> Result<i32, Box<dyn Error>>
Converts a raw slot ID into its local slot ID into whichever of the two inventories the slot points to.
If the raw slot refers to the upper inventory, it will be returned unchanged and thus be suitable for getTopInventory().getItem(); if it refers to the lower inventory, the output will differ from the input and be suitable for getBottomInventory().getItem().
Sourcepub fn get_slot_type(
&self,
slot: i32,
) -> Result<InventoryTypeSlotType<'mc>, Box<dyn Error>>
pub fn get_slot_type( &self, slot: i32, ) -> Result<InventoryTypeSlotType<'mc>, Box<dyn Error>>
Determine the type of the slot by its raw slot ID.
If the type of the slot is unknown, then {@link InventoryType.SlotType#CONTAINER} will be returned.
Sourcepub fn count_slots(&self) -> Result<i32, Box<dyn Error>>
pub fn count_slots(&self) -> Result<i32, Box<dyn Error>>
Check the total number of slots in this view, combining the upper and lower inventories.
Note though that it’s possible for this to be greater than the sum of the two inventories if for example some slots are not being used.
Sourcepub fn set_property(
&self,
prop: impl Into<InventoryViewProperty<'mc>>,
value: i32,
) -> Result<bool, Box<dyn Error>>
pub fn set_property( &self, prop: impl Into<InventoryViewProperty<'mc>>, value: i32, ) -> Result<bool, Box<dyn Error>>
Sets an extra property of this inventory if supported by that inventory, for example the state of a progress bar.
Sourcepub fn original_title(&self) -> Result<String, Box<dyn Error>>
pub fn original_title(&self) -> Result<String, Box<dyn Error>>
Get the original title of this inventory window, before any changes were made using {@link #setTitle(String)}.
Sourcepub fn set_title(&self, title: impl Into<String>) -> Result<(), Box<dyn Error>>
pub fn set_title(&self, title: impl Into<String>) -> Result<(), Box<dyn Error>>
Sets the title of this inventory window to the specified title if the inventory window supports it.
Note if the inventory does not support titles that can be changed (ie, it is not creatable or viewed by a player), then this method will throw an exception.
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>